@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5008 $
+//  $Revision: 5322 $
 //
-//  $LastChangedDate: 2013-10-28 14:12:33 -0700 (Mon, 28 Oct 2013) $
+//  $LastChangedDate: 2014-04-11 15:21:19 -0700 (Fri, 11 Apr 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -49,7 +49,6 @@
 #include <Base/cmtkImageOperation.h>
 #include <Base/cmtkImageOperationConvertType.h>
 #include <Base/cmtkImageOperationFlip.h>
-#include <IO/cmtkImageOperationApplyMask.h>
 #include <Base/cmtkImageOperationErodeDilate.h>
 #include <Base/cmtkImageOperationErodeDilateDistance.h>
 #include <Base/cmtkImageOperationBoundaryMap.h>
@@ -63,6 +62,7 @@
 #include <Base/cmtkImageOperationThreshold.h>
 #include <Base/cmtkImageOperationOtsuThreshold.h>
 #include <Base/cmtkImageOperationPruneHistogram.h>
+#include <Base/cmtkImageOperationSetDataClass.h>
 #include <Base/cmtkImageOperationSetPadding.h>
 #include <Base/cmtkImageOperationMapValues.h>
 #include <Base/cmtkImageOperationReplace.h>
@@ -72,6 +72,9 @@
 #include <Base/cmtkImageOperationDistanceMap.h>
 #include <Base/cmtkImageOperationRevert.h>
 
+#include <IO/cmtkImageOperationApplyMask.h>
+#include <IO/cmtkImageOperationMatchIntensities.h>
+
 #include <stdlib.h>
 #include <iostream>
 #include <fstream>
@@ -110,6 +113,10 @@ doMain( const int argc, const char* argv[] )
     cl.BeginGroup( "Input", "Input Image Controls" );
     cl.AddCallback( Key( "set-padding" ), &cmtk::ImageOperationSetPadding::New, "Set padding value: all pixels in the input image that have this value will be ignored in all subsequent operations." );
     cl.AddCallback( Key( "unset-padding" ), &cmtk::ImageOperationSetPadding::NewUnset, "Unset padding value: for all subsequent operations, all pixels will be treated according to their value." );
+    cl.AddCallback( Key( "labels" ), &cmtk::ImageOperationSetDataClass::NewLabels, "Specify that the image values are to be treated as discrete labels. "
+		    "This will result in the appropriate intent code to be set in output files in NIfTI format." );
+    cl.AddCallback( Key( "grey" ), &cmtk::ImageOperationSetDataClass::NewGrey, "Specify that the image values are to be treated as continuous grey levels. "
+		    "This will reset the intent code in files read from NIfTI format." );
     cl.EndGroup();
 
     cl.BeginGroup( "Conversion", "Data Type Conversion" );
@@ -141,8 +148,9 @@ doMain( const int argc, const char* argv[] )
     cl.EndGroup();
 
     cl.BeginGroup( "MaskAndThreshold", "Image Masking and Thresholding" );
-    cl.AddCallback( Key( "mask" ), &cmtk::ImageOperationApplyMask::New, "Binary mask file name: eliminate all image pixels where mask is 0." );
-    cl.AddCallback( Key( "mask-inverse" ), &cmtk::ImageOperationApplyMask::NewInverse, "Inverse binary mask file name eliminate all image pixels where mask is NOT 0." );
+    cl.AddCallback( Key( "mask" ), &cmtk::ImageOperationApplyMask::New, "Binary mask file name: eliminate all image pixels where mask is 0. "
+		    "Masked-out pixels will NOT be set to zero, but will instead be replaced with the currently-set padding value. Use '--set-padding 0' prior to '--mask' to force setting to zero." );
+    cl.AddCallback( Key( "mask-inverse" ), &cmtk::ImageOperationApplyMask::NewInverse, "Inverse binary mask file name eliminate all image pixels where mask is NOT 0. See also notes regarding padding under '--mask' above." );
 
     cl.AddCallback( Key( "thresh-below" ), &cmtk::ImageOperationThreshold::NewBelow, "Set all values below threshold to threshold value." );
     cl.AddCallback( Key( "thresh-above" ), &cmtk::ImageOperationThreshold::NewAbove, "Set all values above threshold to threshold value." );
@@ -163,7 +171,8 @@ doMain( const int argc, const char* argv[] )
     cl.AddCallback( Key( "scale-to-range" ), &cmtk::ImageOperationScaleToRange::New, "Scale image intensities to range 'from:to', e.g., '0:255' before conversion to byte data." );
     cl.AddCallback( Key( "histogram-equalization" ), &cmtk::ImageOperationHistogramEqualization::New, "Apply histogram equalization." );
     cl.AddCallback( Key( "histogram-equalization-nbins" ), &cmtk::ImageOperationHistogramEqualization::NewBins, "Apply histogram equalization with <int> number of bins." );
-
+    cl.AddCallback( Key( "match-histograms" ), cmtk::ImageOperationMatchIntensities::NewMatchHistograms, "Transform intensities to match the distribution in the image provided as the argument for this command." );
+    cl.AddCallback( Key( "match-mean-sdev" ), cmtk::ImageOperationMatchIntensities::NewMatchMeanSDev, "Scale intensities to match the mean and standard distribution of intensities in the image provided as the argument for this command." );
     cl.EndGroup();
     
     cl.BeginGroup( "Morphological", "Morphological Operations" );
@@ -171,6 +180,8 @@ doMain( const int argc, const char* argv[] )
     cl.AddCallback( Key( "erode" ), &cmtk::ImageOperationErodeDilate::NewErode, "Morphological erosion operator (by pixels)" );
     cl.AddCallback( Key( "dilate" ), &cmtk::ImageOperationErodeDilate::NewDilate, "Morphological dilation operator (by pixels)" );
     cl.AddCallback( Key( "erode-distance" ), &cmtk::ImageOperationErodeDilateDistance::NewErode, "Morphological erosion operator (by distance). Often preferable for anisotropic data." );
+    cl.AddCallback( Key( "erode-distance-multilabel" ), &cmtk::ImageOperationErodeDilateDistance::NewErodeMultiLabels, "Morphological erosion operator (by distance) for multi-label maps. "
+		    "The result will be either byte, unsigned short, or unsigned int data, depending on the index of the largest used label in the input." );
     cl.AddCallback( Key( "dilate-distance" ), &cmtk::ImageOperationErodeDilateDistance::NewDilate, "Morphological dilation operator (by distance). Oftern preferable for anisotropic data." );
     cl.AddCallback( Key( "connected-components" ), &cmtk::ImageOperationConnectedComponents::New, "Create connected components map with regions numbered by decreasing component size" );
     cl.AddCallback( Key( "boundary-map" ), &cmtk::ImageOperationBoundaryMap::New, "Create boundary map" );
@@ -214,6 +225,8 @@ doMain( const int argc, const char* argv[] )
     cl.AddCallback( Key( "downsample-average" ), &cmtk::ImageOperationDownsample::NewAverage, "Downsample image by averaging using per-axis factors 'Fx,Fy,Fz' or using single factor 'Fxyz'" );
     cl.AddCallback( Key( "resample" ), &cmtk::ImageOperationResampleIsotropic::New, "Resample image to near-isotropic pixels while preserving the image field-of-view. "
 		    "Takes one argument, the target resolution in world units [e.g., mm]" );
+    cl.AddCallback( Key( "resample-exact" ), &cmtk::ImageOperationResampleIsotropic::NewExact, "Resample image to exactly isotropic pixels of the given resolution while matching the image field-of-view as closely as possible. "
+		    "Takes one argument, the target resolution in world units [e.g., mm]" );
     cl.AddCallback( Key( "crop-by-index" ), &cmtk::ImageOperationCropRegion::New, "Crop image to a region specified by a set of six grid index coordinates given as comma-separated integers x0,y0,z0,x1,y1,z1" );
     cl.AddCallback( Key( "crop-by-threshold" ), &cmtk::ImageOperationCropThreshold::New, "Crop image to region determined via a given threshold. "
 		    "The resulting image will contain all pixels larger than the given parameter." );
