@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2014 Google Inc.
+//
 //  Copyright 1997-2012 Torsten Rohlfing
 //
 //  Copyright 2004-2014 SRI International
@@ -22,11 +24,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5203 $
+//  $Revision: 5375 $
 //
-//  $LastChangedDate: 2014-02-11 10:52:46 -0800 (Tue, 11 Feb 2014) $
+//  $LastChangedDate: 2014-12-11 17:29:44 -0800 (Thu, 11 Dec 2014) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -328,7 +330,7 @@ VolumeList::AddImageFile( ImageFileDICOM::SmartConstPtr& newImage )
     while ( it != this->end() ) 
       {
       ImageStackDICOM::SmartPtr study = *it;
-      if ( study->Match( *newImage ) ) 
+      if ( study->Match( *newImage, this->m_Tolerance, DisableOrientationCheck, IgnoreAcquisitionNumber) ) 
 	{
 	study->AddImageFile( newImage );
 	return;
