@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2012 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4538 $
+//  $Revision: 4866 $
 //
-//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
+//  $LastChangedDate: 2013-09-24 10:01:06 -0700 (Tue, 24 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -48,9 +48,8 @@
 int
 doMain( const int argc, const char* argv[] )
 {
-  const char* trackingImagePath = NULL;
-
-  const char* outputImagePath = "fib2image.nii";
+  std::string trackingImagePath;
+  std::string outputImagePath = "fib2image.nii";
 
   cmtk::Types::DataItem value = 1;
 
@@ -68,7 +67,7 @@ doMain( const int argc, const char* argv[] )
     
     cl.Parse( argc, argv );
     }
-  catch ( cmtk::CommandLine::Exception ex )
+  catch ( cmtk::CommandLine::Exception& ex )
     {
     cmtk::StdErr << ex << "\n";
     throw cmtk::ExitException( 1 );
