@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2011 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4435 $
+//  $Revision: 5129 $
 //
-//  $LastChangedDate: 2012-06-13 14:10:27 -0700 (Wed, 13 Jun 2012) $
+//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -46,10 +46,10 @@
 int
 doMain ( const int argc, const char *argv[] ) 
 {
-  const char* inputImagePath = NULL;
-  const char *outputPath = NULL;
+  std::string inputImagePath;
+  std::string outputPath;
   
-  const char* gridDims = NULL;
+  std::string gridDims;
   cmtk::Types::Coordinate gridSpacing = 0;
   int levels = 1;
   
@@ -81,7 +81,8 @@ doMain ( const int argc, const char *argv[] )
     cl.EndGroup();
 
     cl.AddParameter( &inputImagePath, "InputImage", "Input image path. This image determines the discrete sampling grid where the target transformation is estimated and fitted." )->SetProperties( cmtk::CommandLine::PROPS_IMAGE );
-    cl.AddParameterVector( &inputXformPaths, "XformList", "List of concatenated transformations. Insert '--inverse' to use the inverse of the transformation listed next." )->SetProperties( cmtk::CommandLine::PROPS_XFORM );
+    cl.AddParameterVector( &inputXformPaths, "XformList", "List of concatenated transformations. Insert '--inverse' to use the inverse of the transformation listed next. "
+			   "(If the first transformation in the sequence is inverted, then '--inverse' must be preceded by '--', i.e., use '-- --inverse xform.path')." )->SetProperties( cmtk::CommandLine::PROPS_XFORM );
  
     cl.Parse( argc, argv );
     }
@@ -91,7 +92,7 @@ doMain ( const int argc, const char *argv[] )
     throw cmtk::ExitException( 1 );
     }
 
-  if ( gridDims && gridSpacing )
+  if ( !gridDims.empty() && gridSpacing )
     {
     cmtk::StdErr << "ERROR: must specify either output spline control point spacing or grid dimensions, but not both.\n";
     throw cmtk::ExitException( 1 );
@@ -107,20 +108,36 @@ doMain ( const int argc, const char *argv[] )
   
   if ( gridSpacing )
     {
-    splineWarp = fitSpline.Fit( gridSpacing, levels, affineFirst );
+    try
+      {
+      splineWarp = fitSpline.Fit( gridSpacing, levels, affineFirst );
+      }
+    catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+      {
+      cmtk::StdErr << "ERROR: singular matrix encountered in cmtk::FitSplineWarpToXformList::Fit()\n";
+      throw cmtk::ExitException( 1 );
+      }   
     }
   else
     {
-    if ( gridDims )
+    if ( !gridDims.empty() )
       {
       double dims[3];
-      if ( 3 != sscanf( gridDims, "%lf,%lf,%lf", &(dims[0]), &(dims[1]), &(dims[2]) ) )
+      if ( 3 != sscanf( gridDims.c_str(), "%20lf,%20lf,%20lf", &(dims[0]), &(dims[1]), &(dims[2]) ) )
 	{
 	cmtk::StdErr << "ERROR: grid dimensions must be specified as dimsX,dimsY,dimsZ\n";
 	throw cmtk::ExitException( 1 );
 	}
-      
-      splineWarp = fitSpline.Fit( cmtk::FixedVector<3,double>::FromPointer( dims ), levels, affineFirst );
+
+      try
+	{
+	splineWarp = fitSpline.Fit( cmtk::FixedVector<3,double>::FromPointer( dims ), levels, affineFirst );
+	}
+      catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+	{
+	cmtk::StdErr << "ERROR: singular matrix encountered in cmtk::FitSplineWarpToXformList::Fit()\n";
+	throw cmtk::ExitException( 1 );
+	}
       }
     else
       {
