@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3976 $
+//  $Revision: 4986 $
 //
-//  $LastChangedDate: 2012-03-06 15:05:34 -0800 (Tue, 06 Mar 2012) $
+//  $LastChangedDate: 2013-10-18 10:30:23 -0700 (Fri, 18 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -40,6 +40,7 @@
 
 #include <Base/cmtkUniformVolume.h>
 #include <Base/cmtkTypedArrayNoiseEstimatorNaiveGaussian.h>
+#include <Base/cmtkHistogramOtsuThreshold.h>
 
 #include <IO/cmtkVolumeIO.h>
 
@@ -54,8 +55,8 @@
 #  include <Registration/cmtkImageXformDB.h>
 #endif
 
-const char* FNameBiasFieldAdd = NULL;
-const char* FNameBiasFieldMul = NULL;
+std::string FNameBiasFieldAdd;
+std::string FNameBiasFieldMul;
 
 cmtk::Types::DataItem PaddingValue = 0;
 bool PaddingFlag = false;
@@ -64,15 +65,16 @@ float ThresholdForegroundMin = -FLT_MAX;
 float ThresholdForegroundMax = FLT_MAX;
 bool ThresholdForegroundFlag = false;
 bool ThresholdAuto = false;
-const char* FNameMaskImage = NULL;
+int ThresholdOtsuNBins = 0;
+std::string FNameMaskImage;
 
 bool UseSamplingDensity = false;
 float SamplingDensity = 1.0;
 
 unsigned int NumberOfHistogramBins = 256;
 
-const char* FNameInputImage = NULL;
-const char* FNameOutputImage = NULL;
+std::string FNameInputImage;
+std::string FNameOutputImage;
 bool OutputFloatImage = false;
 
 int PolynomialDegreeAdd = 0;
@@ -85,7 +87,7 @@ cmtk::Types::Coordinate StepMin = 0.1;
 bool LogIntensities = false;
 
 #ifdef CMTK_USE_SQLITE
-const char* updateDB = NULL;
+std::string updateDB;
 #endif
 
 int
@@ -112,6 +114,7 @@ doMain( const int argc, const char *argv[] )
     cl.AddOption( Key( 't', "thresh-min" ), &ThresholdForegroundMin, "Minimum intensity threshold for image foreground.", &ThresholdForegroundFlag );
     cl.AddOption( Key( 'T', "thresh-max" ), &ThresholdForegroundMax, "Minimum intensity threshold for image foreground.", &ThresholdForegroundFlag );
     cl.AddSwitch( Key( "thresh-auto" ), &ThresholdAuto, true, "Automatic minimum intensity threshold selection for image foreground using an estimate of image noise level." );
+    cl.AddOption( Key( "thresh-otsu-nbins" ), &ThresholdOtsuNBins, "If this is a positive integer, use automatic minimum intensity threshold selection for image foreground by Otsu thresholding with given number of histogram bins." );
     cl.EndGroup();
 
     cl.BeginGroup( "Entropy Estimation", "Entropy Estimation Settings" )->SetProperties( cmtk::CommandLine::PROPS_ADVANCED );
@@ -164,7 +167,7 @@ doMain( const int argc, const char *argv[] )
     }
   
   cmtk::UniformVolume::SmartPtr maskImage;
-  if ( FNameMaskImage )
+  if ( !FNameMaskImage.empty() )
     {
     maskImage = cmtk::UniformVolume::SmartPtr( cmtk::VolumeIO::ReadOriented( FNameMaskImage ) );
     if ( ! maskImage || ! maskImage->GetData() )
@@ -183,6 +186,14 @@ doMain( const int argc, const char *argv[] )
       cmtk::DebugOutput( 1 ) << "INFO: estimated foreground threshold from noise level as " << ThresholdForegroundMin << "\n";
       }
 
+    if ( ThresholdOtsuNBins > 0 )
+      {
+      ThresholdForegroundMin = static_cast<float>( cmtk::HistogramOtsuThreshold< cmtk::Histogram<unsigned int> >( *(inputImage->GetData()->GetHistogram( ThresholdOtsuNBins )) ).Get() );
+      ThresholdForegroundFlag = true;
+
+      cmtk::DebugOutput( 1 ) << "INFO: Otsu thresholding at " << ThresholdForegroundMin << "\n";
+      }
+    
     if ( ThresholdForegroundFlag )
       {
       maskImage = cmtk::UniformVolume::SmartPtr( inputImage->Clone( true /*copyData*/ ) );
@@ -228,7 +239,7 @@ doMain( const int argc, const char *argv[] )
       }
     functional->GetParamVector( v );
     
-    cmtk::DebugOutput( 1 ).GetStream().printf( "Estimating bias field with order %d multiplicative / %d additive polynomials.\nNumber of parameters: %d\n", degreeMul, degreeAdd, v.Dim );
+    cmtk::DebugOutput( 1 ).GetStream().printf( "Estimating bias field with order %u multiplicative / %u additive polynomials.\nNumber of parameters: %d\n", degreeMul, degreeAdd, v.Dim );
     
     if ( (PolynomialDegreeAdd > 0) || (PolynomialDegreeMul > 0) )
       {
@@ -251,7 +262,7 @@ doMain( const int argc, const char *argv[] )
   // make sure everything is according to optimum parameters
   outputImage = functional->GetOutputImage( v, false/*foregroundOnly*/ );
   
-  if ( FNameOutputImage )
+  if ( !FNameOutputImage.empty() )
     {
     if ( ! OutputFloatImage )
       {
@@ -262,38 +273,59 @@ doMain( const int argc, const char *argv[] )
     cmtk::VolumeIO::Write( *outputImage, FNameOutputImage );
 
 #ifdef CMTK_USE_SQLITE
-    if ( updateDB )
+    if ( !updateDB.empty() )
       {
-      cmtk::ImageXformDB db( updateDB );
-      db.AddImage( FNameOutputImage, FNameInputImage );
+      try
+	{
+	cmtk::ImageXformDB db( updateDB );
+	db.AddImage( FNameOutputImage, FNameInputImage );
+	}
+      catch ( const cmtk::SQLite::Exception& ex )
+	{
+	cmtk::StdErr << "ERROR: updating SQLite database failed - " << ex.what() <<  "\n";
+	}	
       }
 #endif
     }
 
-  if ( FNameBiasFieldAdd && PolynomialDegreeAdd )
+  if ( PolynomialDegreeAdd && !FNameBiasFieldAdd.empty() )
     {
     cmtk::UniformVolume::SmartPtr biasField( functional->GetBiasFieldAdd( true /*completeImage*/ ) );
     cmtk::VolumeIO::Write( *biasField, FNameBiasFieldAdd );
 
 #ifdef CMTK_USE_SQLITE
-    if ( updateDB )
+    if ( !updateDB.empty() )
       {
-      cmtk::ImageXformDB db( updateDB );
-      db.AddImage( FNameBiasFieldAdd, FNameInputImage );
+      try
+	{
+	cmtk::ImageXformDB db( updateDB );
+	db.AddImage( FNameBiasFieldAdd, FNameInputImage );
+	}
+      catch ( const cmtk::SQLite::Exception& ex )
+	{
+	cmtk::StdErr << "ERROR: updating SQLite database failed - " << ex.what() <<  "\n";
+	}	
       }
 #endif
     }
 
-  if ( FNameBiasFieldMul && PolynomialDegreeMul )
+  if ( PolynomialDegreeMul && !FNameBiasFieldMul.empty() )
     {
     cmtk::UniformVolume::SmartPtr biasField( functional->GetBiasFieldMul( true /*completeImage*/ ) );
     cmtk::VolumeIO::Write( *biasField, FNameBiasFieldMul );
 
 #ifdef CMTK_USE_SQLITE
-    if ( updateDB )
+    if ( !updateDB.empty() )
       {
-      cmtk::ImageXformDB db( updateDB );
-      db.AddImage( FNameBiasFieldMul, FNameInputImage );
+      try 
+	{
+	cmtk::ImageXformDB db( updateDB );
+	db.AddImage( FNameBiasFieldMul, FNameInputImage );
+	}
+      catch ( const cmtk::SQLite::Exception& ex )
+	{
+	cmtk::StdErr << "ERROR: updating SQLite database failed - " << ex.what() <<  "\n";
+	}	
       }
 #endif
     }
