@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4447 $
+//  $Revision: 4975 $
 //
-//  $LastChangedDate: 2012-07-06 13:51:04 -0700 (Fri, 06 Jul 2012) $
+//  $LastChangedDate: 2013-10-11 13:53:00 -0700 (Fri, 11 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -42,9 +42,9 @@
 #include <Base/cmtkUniformVolume.h>
 #include <IO/cmtkVolumeIO.h>
 
-const char* InputFilePath = NULL;
-const char* OutputFilePath = NULL;
-const char* OutputXformPath = NULL;
+std::string InputFilePath;
+std::string OutputFilePath;
+std::string OutputXformPath;
 
 int Axis = cmtk::AXIS_Z;
 int Factor = 2;
@@ -104,7 +104,7 @@ doMain( const int argc, const char* argv[] )
     cmtk::UniformVolume::SmartPtr subvolume( Padded ? volume->GetInterleavedPaddedSubVolume( Axis, Factor, i ) : volume->GetInterleavedSubVolume( Axis, Factor, i ) );
 
     char path[PATH_MAX];
-    if ( snprintf( path, PATH_MAX, OutputFilePath, i ) > PATH_MAX )
+    if ( snprintf( path, PATH_MAX, OutputFilePath.c_str(), i ) > PATH_MAX )
       {
       cmtk::StdErr << "ERROR: output path exceeds maximum path length\n";
       }
@@ -113,16 +113,25 @@ doMain( const int argc, const char* argv[] )
       cmtk::VolumeIO::Write( *subvolume, path );
       }
 
-    if ( OutputXformPath )
+    if ( !OutputXformPath.empty() )
       {
-      if ( snprintf( path, PATH_MAX, OutputXformPath, i ) > PATH_MAX )
+      if ( snprintf( path, PATH_MAX, OutputXformPath.c_str(), i ) > PATH_MAX )
 	{
 	cmtk::StdErr << "ERROR: output path exceeds maximum path length\n";
 	}
       cmtk::AffineXform xform;
       cmtk::Types::Coordinate xlate[3] = {0,0,0};
       xlate[Axis] = -i * volume->m_Delta[Axis];
-      xform.SetXlate( xlate );
+
+      try
+	{
+	xform.SetXlate( xlate );
+	}
+      catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& ex )
+	{
+	cmtk::StdErr << "ERROR: singular matrix in cmtk::AffineXform::SetXlate()\n";
+	throw cmtk::ExitException( 1 );
+	}
 
       cmtk::ClassStreamOutput stream( path, cmtk::ClassStreamOutput::MODE_WRITE );
       if ( stream.IsValid() )
