@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4427 $
+//  $Revision: 5129 $
 //
-//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -75,7 +75,7 @@ CallbackSetPassWeight( const char* argv )
 {
   int pass = 0;
   float weight = 1.0;
-  if ( 2 == sscanf( argv, "%d:%f", &pass, &weight ) )
+  if ( 2 == sscanf( argv, "%4d:%10f", &pass, &weight ) )
     {
     PassWeights[pass] = weight;
     }
@@ -94,7 +94,7 @@ void
 CallbackCrop( const char* arg )
 {
   int cropFrom[3], cropTo[3];
-  UseCropRegion = (6 == sscanf( arg, "%d,%d,%d,%d,%d,%d", cropFrom, cropFrom+1, cropFrom+2, cropTo,cropTo+1,cropTo+2 ) );
+  UseCropRegion = (6 == sscanf( arg, "%6d,%6d,%6d,%6d,%6d,%6d", cropFrom, cropFrom+1, cropFrom+2, cropTo,cropTo+1,cropTo+2 ) );
 
   if ( UseCropRegion )
     {
@@ -116,10 +116,10 @@ CallbackReconGrid( const char* arg )
   float gridDelta[3] = { 0, 0, 0 };
   float gridOffset[3] = { 0, 0, 0 };
 
-  const size_t numArgs = sscanf( arg, "%d,%d,%d:%f,%f,%f:%f,%f,%f", gridDims, gridDims+1, gridDims+2, gridDelta, gridDelta+1, gridDelta+2, gridOffset, gridOffset+1, gridOffset+2 );
+  const size_t numArgs = sscanf( arg, "%6d,%6d,%6d:%15f,%15f,%15f:%15f,%15f,%15f", gridDims, gridDims+1, gridDims+2, gridDelta, gridDelta+1, gridDelta+2, gridOffset, gridOffset+1, gridOffset+2 );
   if ( (numArgs != 6) && (numArgs != 9) )
     {
-    cmtk::StdErr.printf( "ERROR: reconstruction volume definition must be int,int,int:float,float,float or int,int,int:float,float,float:float,float,float\n", arg );
+    cmtk::StdErr << "ERROR: reconstruction volume definition must be int,int,int:float,float,float or int,int,int:float,float,float:float,float,float\n";
     throw cmtk::ExitException( 1 );
     }
   
@@ -242,8 +242,16 @@ doMain( const int argc, const char* argv[] )
     cmtk::AffineXform::SmartPtr affineXform( cmtk::AffineXform::SmartPtr::DynamicCastFrom( xform ) );
     if ( affineXform && (affineXform->GetMetaInfo( cmtk::META_SPACE ) != cmtk::AnatomicalOrientation::ORIENTATION_STANDARD) )
       {
-      cmtk::TransformChangeFromSpaceAffine toStandardSpace( *affineXform, *ReconGrid, *image );
-      *affineXform = toStandardSpace.GetTransformation();
+      try
+	{
+	cmtk::TransformChangeFromSpaceAffine toStandardSpace( *affineXform, *ReconGrid, *image );
+	*affineXform = toStandardSpace.GetTransformation();
+	}
+      catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+	{
+	cmtk::StdErr << "ERROR: singular matrix encountered in cmtk::TransformChangeFromSpaceAffine constructor\n";
+	throw cmtk::ExitException( 1 );
+	}      
       affineXform->SetMetaInfo( cmtk::META_SPACE, cmtk::AnatomicalOrientation::ORIENTATION_STANDARD );
       }
 
@@ -285,18 +293,34 @@ doMain( const int argc, const char* argv[] )
 					     (float)ReconGrid->m_Offset[0], (float)ReconGrid->m_Offset[1], (float)ReconGrid->m_Offset[2] );
   
   cmtk::VolumeInjectionReconstruction injection( ReconGrid, Images );
-  injection.SetTransformationsToPassImages( Xforms );
+  try
+    {
+    injection.SetTransformationsToPassImages( Xforms );
+    }
+  catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+    {
+    cmtk::StdErr << "ERROR: singular matrix encountered in cmtk::VolumeInjection::SetTransformationsToPassImages()\n";
+    throw cmtk::ExitException( 1 );
+    }
   
   for ( std::map<size_t,float>::const_iterator it = PassWeights.begin(); it != PassWeights.end(); ++it )
     {
     injection.SetPassWeight( it->first, it->second );
     }
   
-  if ( VolumeInjectionIsotropic )
-    injection.VolumeInjectionIsotropic( VolumeInjectionSigma, VolumeInjectionRadius );
-  else
-    injection.VolumeInjectionAnisotropic( VolumeInjectionSigma, VolumeInjectionRadius );
-  
+  try
+    {
+    if ( VolumeInjectionIsotropic )
+      injection.VolumeInjectionIsotropic( VolumeInjectionSigma, VolumeInjectionRadius );
+    else
+      injection.VolumeInjectionAnisotropic( VolumeInjectionSigma, VolumeInjectionRadius );
+    }
+  catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
+    {
+    cmtk::StdErr << "ERROR: singular coordinate transformation matrix encountered in volume injection function\n";
+    throw cmtk::ExitException( 1 );
+    }
+
   if ( OutputImagePath )
     {
     WriteOutputImage( injection.GetCorrectedImage(), OutputImagePath );
