@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5103 $
+//  $Revision: 5249 $
 //
-//  $LastChangedDate: 2014-01-05 14:08:34 -0800 (Sun, 05 Jan 2014) $
+//  $LastChangedDate: 2014-03-20 14:47:29 -0700 (Thu, 20 Mar 2014) $
 //
-//  $LastChangedBy: torsten_at_home $
+//  $LastChangedBy: torstenrohlfing $
 //
 */
 
@@ -408,7 +408,7 @@ doMain( const int argc, const char* argv[] )
 	cmtk::TransformChangeFromSpaceAffine toStandardSpace( *affineXform, *ReconGrid, *image );
 	*affineXform = toStandardSpace.GetTransformation();
 	}
-      catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& ex )
+      catch ( const cmtk::AffineXform::MatrixType::SingularMatrixException& )
 	{
 	cmtk::StdErr << "ERROR: singular matrix encountered in cmtk::TransformChangeFromSpaceAffine constructor\n";
 	throw cmtk::ExitException( 1 );
