@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4834 $
+//  $Revision: 5190 $
 //
-//  $LastChangedDate: 2013-09-12 15:15:51 -0700 (Thu, 12 Sep 2013) $
+//  $LastChangedDate: 2014-01-29 14:54:47 -0800 (Wed, 29 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -62,12 +62,12 @@ cmtk::FusionViewApplication
   CommandLine cl;
   cl.SetProgramInfo( CommandLine::PRG_TITLE, "Fusion viewer." );
 
-  std::string imagePathFix;
-  cl.AddParameter( &imagePathFix, "FixedImage", "Fixed image path. If this is '?', the program attempts to automatically deduce the fixed image path of the first transformation in the given sequence." )
+  std::string imagePathFix = "";
+  cl.AddOption( CommandLine::Key( "fixed" ), &imagePathFix, "Fixed image path. If this is not provided, the program attempts to automatically deduce the fixed image path of the first transformation in the given sequence." )
     ->SetProperties( cmtk::CommandLine::PROPS_IMAGE );
 
-  std::string imagePathMov;
-  cl.AddParameter( &imagePathMov, "MovingImage", "Moving image path. If this is '?', the program attempts to automatically deduce the moving image path of the last transformation in the given sequence." )
+  std::string imagePathMov = "";
+  cl.AddOption( CommandLine::Key( "moving" ), &imagePathMov, "Moving image path. If this is not provided, the program attempts to automatically deduce the fixed image path of the first transformation in the given sequence." )
     ->SetProperties( cmtk::CommandLine::PROPS_IMAGE );
 
   std::vector<std::string> xformList;
@@ -84,9 +84,18 @@ cmtk::FusionViewApplication
     }
 
   this->m_XformList = XformListIO::MakeFromStringList( xformList );
-  this->m_XformListAllAffine = this->m_XformList.MakeAllAffine();
 
-  if ( imagePathFix == "?" )
+  try
+    {
+    this->m_XformListAllAffine = this->m_XformList.MakeAllAffine();
+    }
+  catch ( const AffineXform::MatrixType::SingularMatrixException& )
+    {
+    StdErr << "WARNING: encountered singular matrix when creating affine-only transformation. Will substitute (incorrect) identify transformation instead.\n";
+    this->m_XformListAllAffine = XformList();
+    }
+
+  if ( imagePathFix.empty() )
     {
     imagePathFix = this->m_XformList.GetFixedImagePath();
     if ( !imagePathFix.empty() )
@@ -114,7 +123,7 @@ cmtk::FusionViewApplication
 
   (this->m_CursorPosition = this->m_Fixed.m_Volume->GetDims() ) *= 0.5;
 
-  if ( imagePathMov == "?" )
+  if ( imagePathMov.empty() )
     {
     imagePathMov = this->m_XformList.GetMovingImagePath();
     if ( !imagePathMov.empty() )
