@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4415 $
+//  $Revision: 4538 $
 //
-//  $LastChangedDate: 2012-06-04 14:57:12 -0700 (Mon, 04 Jun 2012) $
+//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -38,18 +38,10 @@ cmtk::AffineXformUniformVolume::AffineXformUniformVolume( const UniformVolume& v
     m_VolumeAxesZ( volume.m_Dims[2] )
 {
   // define volume corners
-  UniformVolume::CoordinateVectorType dX = FixedVectorStaticInitializer<3,Types::Coordinate>::Init(1,0,0);
-  UniformVolume::CoordinateVectorType dY = FixedVectorStaticInitializer<3,Types::Coordinate>::Init(0,1,0);
-  UniformVolume::CoordinateVectorType dZ = FixedVectorStaticInitializer<3,Types::Coordinate>::Init(0,0,1);
-  UniformVolume::CoordinateVectorType V = FixedVectorStaticInitializer<3,Types::Coordinate>::Init(0,0,0);
-  
-  xform.ApplyInPlace(V);
-  xform.ApplyInPlace(dX);
-  dX -= V;
-  xform.ApplyInPlace(dY);
-  dY -= V;
-  xform.ApplyInPlace(dZ);
-  dZ -= V;
+  const UniformVolume::CoordinateVectorType V =  xform.Apply( FixedVectorStaticInitializer<3,Types::Coordinate>::Init(0,0,0) );
+  const UniformVolume::CoordinateVectorType dX = xform.Apply( FixedVectorStaticInitializer<3,Types::Coordinate>::Init(1,0,0) ) - V;
+  const UniformVolume::CoordinateVectorType dY = xform.Apply( FixedVectorStaticInitializer<3,Types::Coordinate>::Init(0,1,0) ) - V;
+  const UniformVolume::CoordinateVectorType dZ = xform.Apply( FixedVectorStaticInitializer<3,Types::Coordinate>::Init(0,0,1) ) - V;
   
   const Types::Coordinate deltaX = volume.m_Delta[0];
   const Types::Coordinate deltaY = volume.m_Delta[1];
