@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4226 $
+//  $Revision: 4415 $
 //
-//  $LastChangedDate: 2012-04-19 13:41:45 -0700 (Thu, 19 Apr 2012) $
+//  $LastChangedDate: 2012-06-04 14:57:12 -0700 (Mon, 04 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -38,8 +38,6 @@
 #include <Base/cmtkTypes.h>
 #include <Base/cmtkMathUtil.h>
 
-#include <math.h>
-#include <stdlib.h>
 #include <limits>
 
 namespace
@@ -49,14 +47,31 @@ cmtk
 /** \addtogroup Base */
 //@{
 
+/// Make signed data types.
+template<class TType> class MakeSigned {};
+
+template<> class MakeSigned<unsigned long int> { public: typedef signed long int Type; };
+template<> class MakeSigned<signed long int> { public: typedef signed long int Type; };
+
+template<> class MakeSigned<unsigned int> { public: typedef signed int Type; };
+template<> class MakeSigned<signed int> { public: typedef signed int Type; };
+
+template<> class MakeSigned<unsigned short int> { public: typedef signed short int Type; };
+template<> class MakeSigned<signed short int> { public: typedef signed short int Type; };
+
+template<> class MakeSigned<unsigned char> { public: typedef signed char Type; };
+template<> class MakeSigned<signed char> { public: typedef signed char Type; };
+
+template<> class MakeSigned<float> { public: typedef float Type; };
+template<> class MakeSigned<double> { public: typedef double Type; };
+
+
 /** Data type traits */
 template<class TType>
 class DataTypeTraits
 {
 public:
-  /** Get the scalar type ID constant for this type. */
-  static ScalarDataType GetScalarDataType() { return TYPE_NONE; }
-
+  /** Scalar type ID constant for this type. */
   static const ScalarDataType DataTypeID = TYPE_NONE;
 };
 
@@ -68,38 +83,33 @@ public:
   /** This class. */
   typedef DataTypeTraits<float> Self;
 
-  /** Get the scalar type ID constant for this type. */
-  static ScalarDataType GetScalarDataType() { return TYPE_FLOAT; }
+  /// The template value type.
+  typedef float ValueType;
 
+  /** Scalar type ID constant for this type. */
   static const ScalarDataType DataTypeID = TYPE_FLOAT;
 
-  /** Get absolute value. */
-  static inline float Abs( const float value ) 
-  {
-    return fabsf( value );
-  }
-
   /** Return given value converted (and rounded) to discrete type. */
   template<class T>
-  static inline float Convert ( const T value, const bool = false, const float = 0 ) 
+  static inline Self::ValueType Convert ( const T value, const bool = false, const Self::ValueType = 0 ) 
   { 
-    return static_cast<float>( value );
+    return static_cast<Self::ValueType>( value );
   }
 
   /** Return padding data value (i.e. Inf) for the given type. */
-  static inline float ChoosePaddingValue () 
+  static inline Self::ValueType ChoosePaddingValue () 
   { 
-    return std::numeric_limits<float>::infinity();
+    return std::numeric_limits<Self::ValueType>::infinity();
   }
 
   /// Return zero value for this type.
-  static inline float Zero()
+  static inline Self::ValueType Zero()
   {
     return 0.0;
   }
 
   /// Return one value (multiplicative identity) for this type.
-  static inline float One()
+  static inline Self::ValueType One()
   {
     return 1.0;
   }
@@ -113,38 +123,33 @@ public:
   /** This class. */
   typedef DataTypeTraits<double> Self;
 
-  /** Get the scalar type ID constant for this type. */
-  static ScalarDataType GetScalarDataType() { return TYPE_DOUBLE; }
+  /// The template value type.
+  typedef double ValueType;
 
+  /** Scalar type ID constant for this type. */
   static const ScalarDataType DataTypeID = TYPE_DOUBLE;
 
-  /** Get absolute value. */
-  static inline double Abs( const double value ) 
-  {
-    return fabs( value );
-  }
-
   /** Return given value converted (and rounded) to discrete type. */
   template<class T>
-  static inline double Convert ( const T value, const bool = false, const double = 0 ) 
+  static inline Self::ValueType Convert ( const T value, const bool = false, const Self::ValueType = 0 ) 
   { 
-    return static_cast<double>( value );
+    return static_cast<Self::ValueType>( value );
   }
   
   /** Return padding data value (i.e. Inf) for the given type. */
-  static inline double ChoosePaddingValue () 
+  static inline Self::ValueType ChoosePaddingValue () 
   { 
-    return std::numeric_limits<double>::infinity();
+    return std::numeric_limits<Self::ValueType>::infinity();
   }
 
   /// Return zero value for this type.
-  static inline double Zero()
+  static inline Self::ValueType Zero()
   {
     return 0.0;
   }
 
   /// Return one value (multiplicative identity) for this type.
-  static inline double One()
+  static inline Self::ValueType One()
   {
     return 1.0;
   }
@@ -158,31 +163,20 @@ public:
   /** This class. */
   typedef DataTypeTraits<byte> Self;
 
-  /** Get the scalar type ID constant for this type. */
-  static ScalarDataType GetScalarDataType() { return TYPE_BYTE; }
+  /// The template value type.
+  typedef byte ValueType;
 
+  /** Scalar type ID constant for this type. */
   static const ScalarDataType DataTypeID = TYPE_BYTE;
 
-  /** Minimum value in this type. */
-  static const Types::DataItem Min;
-
-  /** Maximum value in this type. */
-  static const Types::DataItem Max;
-
-  /** Get absolute value. */
-  static inline byte Abs( const byte value ) 
-  {
-    return abs( value );
-  }
-
   /** Return given value converted (and rounded) to discrete type. */
   template<class T>
-  static inline byte Convert ( const T value, const bool paddingFlag = false, const byte paddingData = 0 ) 
+  static inline Self::ValueType Convert ( const T value, const bool paddingFlag = false, const Self::ValueType paddingData = 0 ) 
   { 
     using namespace std;
     if ( MathUtil::IsFinite( value ) )
       {
-      return (byte) ((value<Self::Min) ? Self::Min : (value+0.5>Self::Max) ? Self::Max : floor(value+0.5));
+      return (Self::ValueType) ((value<std::numeric_limits<Self::ValueType>::min()) ? std::numeric_limits<Self::ValueType>::min() : (value+0.5>std::numeric_limits<Self::ValueType>::max()) ? std::numeric_limits<Self::ValueType>::max() : floor(value+0.5));
       }
     else
       {
@@ -194,19 +188,19 @@ public:
   }
   
   /** Return padding data value for the given type. */
-  static inline byte ChoosePaddingValue () 
+  static inline Self::ValueType ChoosePaddingValue () 
   { 
     return 255;
   }
 
   /// Return zero value for this type.
-  static inline byte Zero()
+  static inline Self::ValueType Zero()
   {
     return 0;
   }
 
   /// Return one value (multiplicative identity) for this type.
-  static inline byte One()
+  static inline Self::ValueType One()
   {
     return 1;
   }
@@ -220,31 +214,20 @@ public:
   /** This class. */
   typedef DataTypeTraits<char> Self;
 
-  /** Get the scalar type ID constant for this type. */
-  static ScalarDataType GetScalarDataType() { return TYPE_CHAR; }
+  /// The template value type.
+  typedef char ValueType;
 
+  /** Scalar type ID constant for this type. */
   static const ScalarDataType DataTypeID = TYPE_CHAR;
 
-  /** Minimum value in this type. */
-  static const Types::DataItem Min;
-
-  /** Maximum value in this type. */
-  static const Types::DataItem Max;
-
-  /** Get absolute value. */
-  static inline char Abs( const char value ) 
-  {
-    return abs( value );
-  }
-
   /** Return given value converted (and rounded) to discrete type. */
   template<class T>
-  static inline char Convert ( const T value, const bool paddingFlag = false, const char paddingData = 0 ) 
+  static inline Self::ValueType Convert ( const T value, const bool paddingFlag = false, const Self::ValueType paddingData = 0 ) 
   { 
     using namespace std;
     if ( MathUtil::IsFinite( value ) )
       {
-      return (char) ((value<Self::Min) ? Self::Min : (value+0.5>Self::Max) ? Self::Max : floor(value+0.5));
+      return (Self::ValueType) ((value<std::numeric_limits<Self::ValueType>::min()) ? std::numeric_limits<Self::ValueType>::min() : (value+0.5>std::numeric_limits<Self::ValueType>::max()) ? std::numeric_limits<Self::ValueType>::max() : floor(value+0.5));
       }
     else
       {
@@ -256,19 +239,19 @@ public:
   }
   
   /** Return padding data value for the given type. */
-  static inline char ChoosePaddingValue () 
+  static inline Self::ValueType ChoosePaddingValue () 
   { 
     return -1;
   }
 
   /// Return zero value for this type.
-  static inline char Zero()
+  static inline Self::ValueType Zero()
   {
     return 0;
   }
 
   /// Return one value (multiplicative identity) for this type.
-  static inline char One()
+  static inline Self::ValueType One()
   {
     return 1;
   }
@@ -282,31 +265,20 @@ public:
   /** This class. */
   typedef DataTypeTraits<signed short> Self;
 
-  /** Get the scalar type ID constant for this type. */
-  static ScalarDataType GetScalarDataType() { return TYPE_SHORT; }
+  /// The template value type.
+  typedef signed short ValueType;
 
+  /** Scalar type ID constant for this type. */
   static const ScalarDataType DataTypeID = TYPE_SHORT;
 
-  /** Minimum value in this type. */
-  static const Types::DataItem Min;
-
-  /** Maximum value in this type. */
-  static const Types::DataItem Max;
-
-  /** Get absolute value. */
-  static inline signed short Abs( const signed short value ) 
-  {
-    return abs( value );
-  }
-
   /** Return given value converted (and rounded) to discrete type. */
   template<class T>
-  static inline signed short Convert ( const T value, const bool paddingFlag = false, const signed short paddingData = 0 ) 
+  static inline Self::ValueType Convert ( const T value, const bool paddingFlag = false, const Self::ValueType paddingData = 0 ) 
   { 
     using namespace std;
     if ( MathUtil::IsFinite( value ) )
       {
-      return (signed short) (((value<Self::Min) ? Self::Min : (value+0.5>Self::Max) ? Self::Max : floor(value+0.5)));
+      return (Self::ValueType) (((value<std::numeric_limits<Self::ValueType>::min()) ? std::numeric_limits<Self::ValueType>::min() : (value+0.5>std::numeric_limits<Self::ValueType>::max()) ? std::numeric_limits<Self::ValueType>::max() : floor(value+0.5)));
       }
     else
       {
@@ -318,19 +290,19 @@ public:
   }
   
   /** Return padding data value for the given type. */
-  static inline signed short ChoosePaddingValue () 
+  static inline Self::ValueType ChoosePaddingValue () 
   { 
     return -1;
   }
 
   /// Return zero value for this type.
-  static inline signed short Zero()
+  static inline Self::ValueType Zero()
   {
     return 0;
   }
 
   /// Return one value (multiplicative identity) for this type.
-  static inline signed short One()
+  static inline Self::ValueType One()
   {
     return 1;
   }
@@ -344,31 +316,20 @@ public:
   /** This class. */
   typedef DataTypeTraits<unsigned short> Self;
 
-  /** Get the scalar type ID constant for this type. */
-  static ScalarDataType GetScalarDataType() { return TYPE_USHORT; }
+  /// The template value type.
+  typedef unsigned short ValueType;
 
+  /** Scalar type ID constant for this type. */
   static const ScalarDataType DataTypeID = TYPE_USHORT;
 
-  /** Minimum value in this type. */
-  static const Types::DataItem Min;
-
-  /** Maximum value in this type. */
-  static const Types::DataItem Max;
-
-  /** Get absolute value. */
-  static inline unsigned short Abs( const unsigned short value ) 
-  {
-    return abs( value );
-  }
-
   /** Return given value converted (and rounded) to discrete type. */
   template<class T>
-  static inline unsigned short Convert ( const T value, const bool paddingFlag = false, const unsigned short paddingData = 0 ) 
+  static inline Self::ValueType Convert ( const T value, const bool paddingFlag = false, const Self::ValueType paddingData = 0 ) 
   { 
     using namespace std;
     if ( MathUtil::IsFinite( value ) )
       {
-      return (unsigned short) ((value<Self::Min) ? Self::Min : (value+0.5>Self::Max) ? Self::Max : floor(value+0.5));
+      return (Self::ValueType) ((value<std::numeric_limits<Self::ValueType>::min()) ? std::numeric_limits<Self::ValueType>::min() : (value+0.5>std::numeric_limits<Self::ValueType>::max()) ? std::numeric_limits<Self::ValueType>::max() : floor(value+0.5));
       }
     else
       {
@@ -380,19 +341,19 @@ public:
   }
   
   /** Return padding data value for the given type. */
-  static inline unsigned short ChoosePaddingValue () 
+  static inline Self::ValueType ChoosePaddingValue () 
   { 
-    return USHRT_MAX;
+    return std::numeric_limits<Self::ValueType>::max();
   }
 
   /// Return zero value for this type.
-  static inline unsigned short Zero()
+  static inline Self::ValueType Zero()
   {
     return 0;
   }
 
   /// Return one value (multiplicative identity) for this type.
-  static inline unsigned short One()
+  static inline Self::ValueType One()
   {
     return 1;
   }
@@ -406,31 +367,20 @@ public:
   /** This class. */
   typedef DataTypeTraits<int> Self;
 
-  /** Get the scalar type ID constant for this type. */
-  static ScalarDataType GetScalarDataType() { return TYPE_INT; }
+  /// The template value type.
+  typedef int ValueType;
 
+  /** Scalar type ID constant for this type. */
   static const ScalarDataType DataTypeID = TYPE_INT;
 
-  /** Minimum value in this type. */
-  static const Types::DataItem Min;
-
-  /** Maximum value in this type. */
-  static const Types::DataItem Max;
-
-  /** Get absolute value. */
-  static inline int Abs( const int value ) 
-  {
-    return abs( value );
-  }
-
   /** Return given value converted (and rounded) to discrete type. */
   template<class T>
-  static inline int Convert ( const T value, const bool paddingFlag = false, const int paddingData = 0 ) 
+  static inline Self::ValueType Convert ( const T value, const bool paddingFlag = false, const Self::ValueType paddingData = 0 ) 
   { 
     using namespace std;
     if ( MathUtil::IsFinite( value ) )
       {
-      return (int) ((value<Self::Min) ? Self::Min : (value+0.5>Self::Max) ? Self::Max : floor(value+0.5));
+      return (Self::ValueType) ((value<std::numeric_limits<Self::ValueType>::min()) ? std::numeric_limits<Self::ValueType>::min() : (value+0.5>std::numeric_limits<Self::ValueType>::max()) ? std::numeric_limits<Self::ValueType>::max() : floor(value+0.5));
       }
     else
       {
@@ -442,19 +392,19 @@ public:
   }
   
   /** Return padding data value for the given type. */
-  static inline int ChoosePaddingValue () 
+  static inline Self::ValueType ChoosePaddingValue () 
   { 
     return -1;
   }
 
   /// Return zero value for this type.
-  static inline int Zero()
+  static inline Self::ValueType Zero()
   {
     return 0;
   }
 
   /// Return one value (multiplicative identity) for this type.
-  static inline int One()
+  static inline Self::ValueType One()
   {
     return 1;
   }
@@ -468,32 +418,20 @@ public:
   /** This class. */
   typedef DataTypeTraits<unsigned int> Self;
 
-  /** Get the scalar type ID constant for this type. */
-  static ScalarDataType GetScalarDataType() { return TYPE_UINT; }
+  /// The template value type.
+  typedef unsigned int ValueType;
 
+  /** Scalar type ID constant for this type. */
   static const ScalarDataType DataTypeID = TYPE_UINT;
 
-  /** Minimum value in this type. */
-  static const Types::DataItem Min;
-
-  /** Maximum value in this type. */
-  static const Types::DataItem Max;
-
-  /** Get absolute value. */
-  static inline unsigned int Abs( const unsigned int value ) 
-  {
-    // usigned is always positive
-    return value;
-  }
-
   /** Return given value converted (and rounded) to discrete type. */
   template<class T>
-  static inline unsigned int Convert ( const T value, const bool paddingFlag = false, const unsigned int paddingData = 0 ) 
+  static inline Self::ValueType Convert ( const T value, const bool paddingFlag = false, const Self::ValueType paddingData = 0 ) 
   { 
     using namespace std;
     if ( MathUtil::IsFinite( value ) )
       {
-      return (unsigned int) ((value<Self::Min) ? Self::Min : (value+0.5>Self::Max) ? Self::Max : floor(value+0.5));
+      return (Self::ValueType) ((static_cast<Self::ValueType>( value ) < std::numeric_limits<Self::ValueType>::min()) ? std::numeric_limits<Self::ValueType>::min() : (value+0.5>std::numeric_limits<Self::ValueType>::max()) ? std::numeric_limits<Self::ValueType>::max() : floor(value+0.5));
       }
     else
       {
@@ -505,19 +443,19 @@ public:
   }
   
   /** Return padding data value for the given type. */
-  static inline unsigned int ChoosePaddingValue () 
+  static inline Self::ValueType ChoosePaddingValue () 
   { 
-    return static_cast<unsigned int>( -1 );
+    return static_cast<Self::ValueType>( -1 );
   }
 
   /// Return zero value for this type.
-  static inline unsigned int Zero()
+  static inline Self::ValueType Zero()
   {
     return 0;
   }
 
   /// Return one value (multiplicative identity) for this type.
-  static inline unsigned int One()
+  static inline Self::ValueType One()
   {
     return 1;
   }
