@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2016 Google, Inc.
+//
 //  Copyright 1997-2009 Torsten Rohlfing
 //
 //  Copyright 2004-2011 SRI International
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3662 $
+//  $Revision: 5418 $
 //
-//  $LastChangedDate: 2011-12-23 09:56:34 -0800 (Fri, 23 Dec 2011) $
+//  $LastChangedDate: 2016-01-20 20:15:12 -0800 (Wed, 20 Jan 2016) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -33,6 +35,8 @@
 #ifndef __cmtkFilterVolume_h_included_
 #define __cmtkFilterVolume_h_included_
 
+#include <list>
+
 #include <cmtkconfig.h>
 
 #include <Base/cmtkUniformVolume.h>
