@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4156 $
+//  $Revision: 4375 $
 //
-//  $LastChangedDate: 2012-04-10 10:13:18 -0700 (Tue, 10 Apr 2012) $
+//  $LastChangedDate: 2012-05-30 13:01:18 -0700 (Wed, 30 May 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -32,6 +32,8 @@
 
 #include "cmtkHistogram.h"
 
+#include <limits>
+
 namespace
 cmtk
 {
@@ -67,7 +69,7 @@ Histogram<T>
   
   const T sampleCount = this->SampleCount();
   if ( ! sampleCount ) 
-    return MathUtil::GetDoubleNaN();
+    return std::numeric_limits<double>::signaling_NaN();
   
   for ( size_t i=0; i<this->GetNumberOfBins(); ++i ) 
     {
