@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2016 Google, Inc.
+//
 //  Copyright 1997-2009 Torsten Rohlfing
 //
 //  Copyright 2004-2010, 2013 SRI International
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4907 $
+//  $Revision: 5400 $
 //
-//  $LastChangedDate: 2013-10-01 11:49:29 -0700 (Tue, 01 Oct 2013) $
+//  $LastChangedDate: 2016-01-14 19:42:40 -0800 (Thu, 14 Jan 2016) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -125,6 +127,7 @@ JointHistogram<T>::GetMarginalY() const
 
 template class JointHistogram<int>;
 template class JointHistogram<unsigned int>;
+template class JointHistogram<long long int>;
 template class JointHistogram<float>;
 template class JointHistogram<double>;
 
