@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4451 $
+//  $Revision: 5220 $
 //
-//  $LastChangedDate: 2012-07-06 16:27:40 -0700 (Fri, 06 Jul 2012) $
+//  $LastChangedDate: 2014-03-04 13:19:27 -0800 (Tue, 04 Mar 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -56,6 +56,21 @@ const char* const META_IMAGE_DESCRIPTION = "IMAGE_DESCRIPTION";
 
 const char* const META_IMAGE_DIRECTION_VECTORS = "IMAGE_DIRECTION_VECTORS";
 
+// Slice order (ascending/descending, sequential/interleaved)
+const char* const META_IMAGE_SLICEORDER = "IMAGE_SLICEORDER";
+const char* const META_IMAGE_SLICEORDER_SI = "SEQ-INC";
+const char* const META_IMAGE_SLICEORDER_SD = "SEQ-DEC";
+const char* const META_IMAGE_SLICEORDER_AI = "ALT-INC";
+const char* const META_IMAGE_SLICEORDER_AD = "ALT-DEC";
+const char* const META_IMAGE_SLICEORDER_AI2 = "ALT-INC2";
+const char* const META_IMAGE_SLICEORDER_AD2 = "ALT-DEC2";
+
+// Slice time (duration for one slice; this should be TR/nSlices)
+const char* const META_IMAGE_SLICEDURATION = "IMAGE_SLICEDURATION";
+
+// Phase encode direction within slice - this should be either "COL" (y) or "ROW" (x), as delivered by DICOM tag InPlanePhaseEncodingDirection
+const char* const META_IMAGE_SLICE_PEDIRECTION = "IMAGE_SLICE_PEDIRECTION";
+
 const char* const META_XFORM_FIXED_IMAGE_PATH = "XFORM_FIXED_IMAGE_PATH";
 const char* const META_XFORM_MOVING_IMAGE_PATH = "XFORM_MOVING_IMAGE_PATH";
 
