@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3709 $
+//  $Revision: 5240 $
 //
-//  $LastChangedDate: 2012-01-10 12:59:36 -0800 (Tue, 10 Jan 2012) $
+//  $LastChangedDate: 2014-03-18 14:30:29 -0700 (Tue, 18 Mar 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -60,6 +60,9 @@ public:
   /// Size of the interpolation region in grid points to the left and right.
   static const int RegionSizeLeftRight = NRadius;
 
+  /// Flag whether this interpolator is suitable for labels.
+  static const bool SuitableForLabels = false;
+
   /// Get specific interpolation weight for relative coordinate.
   static Types::Coordinate GetWeight( const int i, const Types::Coordinate x )
   {
@@ -83,6 +86,9 @@ public:
   /// This class.
   typedef CosineSinc<NRadius> Self;
 
+  /// Flag whether this interpolator is suitable for labels.
+  static const bool SuitableForLabels = false;
+
   /// Size of the interpolation region in grid points to the left and right.
   static const int RegionSizeLeftRight = NRadius;
 
