@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4870 $
+//  $Revision: 5160 $
 //
-//  $LastChangedDate: 2013-09-24 11:01:11 -0700 (Tue, 24 Sep 2013) $
+//  $LastChangedDate: 2014-01-12 14:33:52 -0800 (Sun, 12 Jan 2014) $
 //
-//  $LastChangedBy: torstenrohlfing $
+//  $LastChangedBy: torsten_at_home $
 //
 */
 
@@ -156,7 +156,7 @@ SplineWarpXform::GetJacobianRow
   }
 }
 
-CoordinateMatrix3x3
+const CoordinateMatrix3x3
 SplineWarpXform::GetJacobianAtControlPoint
 ( const Types::Coordinate* cp ) const
 {
@@ -200,7 +200,7 @@ SplineWarpXform::GetJacobianAtControlPoint
   return J;
 }
 
-CoordinateMatrix3x3
+const CoordinateMatrix3x3
 SplineWarpXform::GetJacobian
 ( const Self::SpaceVectorType& v ) const
 {
