@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2011 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4395 $
+//  $Revision: 4882 $
 //
-//  $LastChangedDate: 2012-05-31 11:02:03 -0700 (Thu, 31 May 2012) $
+//  $LastChangedDate: 2013-09-27 15:16:36 -0700 (Fri, 27 Sep 2013) $
 //
-//  $LastChangedBy: torsten_at_home $
+//  $LastChangedBy: torstenrohlfing $
 //
 */
 
@@ -117,7 +117,8 @@ public:
   /** Constructor.
    * Allocate an array of a given size.
    */
-  TemplateArray ( const size_t datasize = 0 ) 
+  TemplateArray ( const size_t datasize = 0 )  
+    : Padding( 0 )
   {
     m_DataType = TypeTraits::DataTypeID;
     Data = NULL;
