@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2016 Google, Inc.
+//
 //  Copyright 1997-2009 Torsten Rohlfing
 //
 //  Copyright 2004-2010 SRI International
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5240 $
+//  $Revision: 5399 $
 //
-//  $LastChangedDate: 2014-03-18 14:30:29 -0700 (Tue, 18 Mar 2014) $
+//  $LastChangedDate: 2016-01-14 19:00:40 -0800 (Thu, 14 Jan 2016) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -93,7 +95,7 @@ public:
    */
   virtual bool GetDataAt( const Vector3D& v, Types::DataItem& value ) const;
 
-  virtual Types::DataItem GetDataDirect( const int* imageGridPoint, const Types::Coordinate* insidePixel ) const;
+  virtual Types::DataItem GetDataDirect( const Types::GridIndexType* imageGridPoint, const Types::Coordinate* insidePixel ) const;
 };
 
 //@}
