@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2016 Google, Inc.
+//
 //  Copyright 1997-2009 Torsten Rohlfing
 //
 //  Copyright 2004-2012 SRI International
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4381 $
+//  $Revision: 5398 $
 //
-//  $LastChangedDate: 2012-05-30 14:18:15 -0700 (Wed, 30 May 2012) $
+//  $LastChangedDate: 2016-01-14 18:29:18 -0800 (Thu, 14 Jan 2016) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -66,19 +68,19 @@ cmtk::UniformVolumePainter::DrawSphere
   DataGrid::RegionType region = volume.GetWholeImageRegion();
   for ( int dim = 0; dim < 3; ++dim )
     {
-    region.From()[dim] = std::max( region.From()[dim], static_cast<int>( (centerAbsolute[dim] - radiusAbsolute[dim] - volume.m_Offset[dim]) / volume.m_Delta[dim] ) - 1 );
-    region.To()[dim] = std::min( region.To()[dim], static_cast<int>( (centerAbsolute[dim] + radiusAbsolute[dim] - volume.m_Offset[dim]) / volume.m_Delta[dim] ) + 1 );
+    region.From()[dim] = std::max( region.From()[dim], static_cast<Types::GridIndexType>( (centerAbsolute[dim] - radiusAbsolute[dim] - volume.m_Offset[dim]) / volume.m_Delta[dim] ) - 1 );
+    region.To()[dim] = std::min( region.To()[dim], static_cast<Types::GridIndexType>( (centerAbsolute[dim] + radiusAbsolute[dim] - volume.m_Offset[dim]) / volume.m_Delta[dim] ) + 1 );
     }
 
-  for ( int k = region.From()[2]; k < region.To()[2]; ++k )
+  for ( Types::GridIndexType k = region.From()[2]; k < region.To()[2]; ++k )
     {
     const Types::Coordinate Z = volume.GetPlaneCoord( 2, k );
-    for ( int j = region.From()[1]; j < region.To()[1]; ++j )
+    for ( Types::GridIndexType j = region.From()[1]; j < region.To()[1]; ++j )
       {
       const Types::Coordinate Y = volume.GetPlaneCoord( 1, j );
       
       size_t offset = region.From()[0] + volume.m_Dims[0] * ( j + volume.m_Dims[1] * k );
-      for ( int i = region.From()[0]; i < region.To()[0]; ++i, ++offset )
+      for ( Types::GridIndexType i = region.From()[0]; i < region.To()[0]; ++i, ++offset )
 	{
 	const Types::Coordinate X = volume.GetPlaneCoord( 0, i );
 	
@@ -103,7 +105,7 @@ cmtk::UniformVolumePainter::DrawBox
 {
   UniformVolume& volume = *(this->m_Volume);
 
-  int indexFrom[3], indexTo[3];
+  Types::GridIndexType indexFrom[3], indexTo[3];
 
   switch ( this->m_CoordinateMode )
     {
@@ -111,23 +113,23 @@ cmtk::UniformVolumePainter::DrawBox
     case Self::COORDINATES_ABSOLUTE:
       for ( int dim = 0; dim < 3; ++dim )
 	{
-	indexFrom[dim] = static_cast<int>( MathUtil::Round( boxFrom[dim] / volume.m_Delta[dim] ) );
-	indexTo[dim] = static_cast<int>( MathUtil::Round( boxTo[dim] / volume.m_Delta[dim] ) );
+	indexFrom[dim] = static_cast<Types::GridIndexType>( MathUtil::Round( boxFrom[dim] / volume.m_Delta[dim] ) );
+	indexTo[dim] = static_cast<Types::GridIndexType>( MathUtil::Round( boxTo[dim] / volume.m_Delta[dim] ) );
 	}
       break;
     case Self::COORDINATES_RELATIVE:
       for ( int dim = 0; dim < 3; ++dim )
 	{
-	indexFrom[dim] = static_cast<int>( MathUtil::Round( boxFrom[dim] * volume.m_Size[dim] / volume.m_Delta[dim] ) );
-	indexTo[dim] = static_cast<int>( MathUtil::Round( boxTo[dim] * volume.m_Size[dim] / volume.m_Delta[dim] ) );
+	indexFrom[dim] = static_cast<Types::GridIndexType>( MathUtil::Round( boxFrom[dim] * volume.m_Size[dim] / volume.m_Delta[dim] ) );
+	indexTo[dim] = static_cast<Types::GridIndexType>( MathUtil::Round( boxTo[dim] * volume.m_Size[dim] / volume.m_Delta[dim] ) );
 	}
       break;
     case Self::COORDINATES_INDEXED:
       // nothing to do - already indexed
       for ( int dim = 0; dim < 3; ++dim )
 	{
-	indexFrom[dim] = static_cast<int>( boxFrom[dim] + 0.5 );
-	indexTo[dim] = static_cast<int>( boxTo[dim] + 0.5 );
+	indexFrom[dim] = static_cast<Types::GridIndexType>( boxFrom[dim] + 0.5 );
+	indexTo[dim] = static_cast<Types::GridIndexType>( boxTo[dim] + 0.5 );
 	}
       break;
     }
@@ -138,15 +140,15 @@ cmtk::UniformVolumePainter::DrawBox
     if ( indexFrom[dim] > indexTo[dim] )
       std::swap( indexFrom[dim], indexTo[dim] );
 
-    indexFrom[dim] = std::max( 0, std::min( volume.m_Dims[dim]-1, indexFrom[dim] ) );
-    indexTo[dim] = std::max( 0, std::min( volume.m_Dims[dim]-1, indexTo[dim] ) );
+    indexFrom[dim] = std::max<Types::GridIndexType>( 0, std::min( volume.m_Dims[dim]-1, indexFrom[dim] ) );
+    indexTo[dim] = std::max<Types::GridIndexType>( 0, std::min( volume.m_Dims[dim]-1, indexTo[dim] ) );
     }
   
-  for ( int k = indexFrom[2]; k <= indexTo[2]; ++k )
+  for ( Types::GridIndexType k = indexFrom[2]; k <= indexTo[2]; ++k )
     {
-    for ( int j = indexFrom[1]; j <= indexTo[1]; ++j )
+    for ( Types::GridIndexType j = indexFrom[1]; j <= indexTo[1]; ++j )
       {
-      for ( int i = indexFrom[0]; i <= indexTo[0]; ++i )
+      for ( Types::GridIndexType i = indexFrom[0]; i <= indexTo[0]; ++i )
 	{
 	volume.SetDataAt( value, volume.GetOffsetFromIndex( i, j, k ) );
 	}
