@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2010, 2011 SRI International
+//  Copyright 2010-2012 SRI International
 //
 //  Copyright 2010 Torsten Rohlfing
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3671 $
+//  $Revision: 4043 $
 //
-//  $LastChangedDate: 2011-12-23 11:46:03 -0800 (Fri, 23 Dec 2011) $
+//  $LastChangedDate: 2012-03-20 14:29:11 -0700 (Tue, 20 Mar 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -146,8 +146,8 @@ public:
   inline Radians( const Degrees& degrees );
 };
 
-inline Degrees::Degrees( const Radians& radians ) : UnitBase( radians.Value() / (UnitBase::Pi() / 180) ) {};
-inline Radians::Radians( const Degrees& degrees ) : UnitBase( degrees.Value() * (UnitBase::Pi() / 180) ) {};
+inline Degrees::Degrees( const Radians& radians ) : UnitBase( radians.Value() / (UnitBase::Pi() / 180) ) {}
+inline Radians::Radians( const Degrees& degrees ) : UnitBase( degrees.Value() * (UnitBase::Pi() / 180) ) {}
 
 /// Forward declaration.
 class GaussianFWHM;
@@ -176,8 +176,8 @@ public:
   inline GaussianFWHM( const GaussianSigma& degrees );
 };
 
-inline GaussianSigma::GaussianSigma( const GaussianFWHM& fwhm ) : UnitBase( fwhm.Value() / 2.354820045 ) {};
-inline GaussianFWHM::GaussianFWHM( const GaussianSigma& sigma ) : UnitBase( sigma.Value() * 2.354820045 ) {};
+inline GaussianSigma::GaussianSigma( const GaussianFWHM& fwhm ) : UnitBase( fwhm.Value() / 2.354820045 ) {}
+inline GaussianFWHM::GaussianFWHM( const GaussianSigma& sigma ) : UnitBase( sigma.Value() * 2.354820045 ) {}
 
 }
 
