@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4342 $
+//  $Revision: 4879 $
 //
-//  $LastChangedDate: 2012-05-11 11:36:24 -0700 (Fri, 11 May 2012) $
+//  $LastChangedDate: 2013-09-26 15:08:17 -0700 (Thu, 26 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -37,6 +37,8 @@
 
 #include <IO/cmtkStudyList.h>
 
+#include <string>
+
 namespace
 cmtk
 {
@@ -50,7 +52,7 @@ class ClassStreamStudyList
 {
 public:
   /// Write studylist.
-  static void Write( const char *path, const StudyList *studyList );
+  static void Write( const std::string& path, const StudyList *studyList );
 };
 
 //@}
