@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2014-2015 Google Inc.
+//
 //  Copyright 2004-2014 SRI International
 //
 //  Copyright 1997-2009 Torsten Rohlfing
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5347 $
+//  $Revision: 5391 $
 //
-//  $LastChangedDate: 2014-05-01 15:26:43 -0700 (Thu, 01 May 2014) $
+//  $LastChangedDate: 2015-11-02 19:37:40 -0800 (Mon, 02 Nov 2015) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -53,6 +55,22 @@
 #include <stdio.h>
 #include <ctime>
 
+#ifndef DCM_ACR_NEMA_ImagePosition
+#  define DCM_ACR_NEMA_ImagePosition DcmTagKey(0x0020, 0x0030)
+#endif
+
+#ifndef DCM_ACR_NEMA_ImageOrientation
+#  define DCM_ACR_NEMA_ImageOrientation DcmTagKey(0x0020, 0x0035)
+#endif
+
+#ifndef DCM_ACR_NEMA_Location
+#  define DCM_ACR_NEMA_Location DcmTagKey(0x0020, 0x0050)
+#endif
+
+#ifndef DCM_ACR_NEMA_2C_VariablePixelData
+#  define DCM_ACR_NEMA_2C_VariablePixelData DcmTagKey(0x7f00, 0x0010)
+#endif
+
 namespace
 cmtk
 {
@@ -313,6 +331,12 @@ DICOM::GetPixelDataArray( const size_t pixelDataLength )
     
   if ( haveRescaleIntercept || haveRescaleSlope ) 
     {
+    double intpart = 0;
+    if ( fabs(modf(rescaleSlope, &intpart) / rescaleSlope) > 1e-5 ) 
+      {
+      pixelDataArray = pixelDataArray->Convert(TYPE_FLOAT);
+      }
+    
     pixelDataArray->Rescale( rescaleSlope, rescaleIntercept );
     }
 
