@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2004-2013 SRI International
+//  Copyright 2004-2014 SRI International
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
@@ -44,6 +44,8 @@
 
 #include <mxml.h>
 
+#include <vector>
+
 namespace
 cmtk
 {
@@ -103,6 +105,9 @@ private:
   /// Stored floating point tolerance.
   Types::Coordinate m_Tolerance;
 
+  /// Assemble slice times vector from current set of slices.
+  std::vector<double> AssembleSliceTimes() const;
+
   /// Generate custom whitespaces for XML output.
   static const char *WhitespaceWriteMiniXML( mxml_node_t*, int where);
 };
