@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2016 Google, Inc.
+//
 //  Copyright 1997-2009 Torsten Rohlfing
 //
 //  Copyright 2004-2013 SRI International
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4957 $
+//  $Revision: 5398 $
 //
-//  $LastChangedDate: 2013-10-10 16:29:27 -0700 (Thu, 10 Oct 2013) $
+//  $LastChangedDate: 2016-01-14 18:29:18 -0800 (Thu, 14 Jan 2016) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -513,6 +515,61 @@ TypedStreamOutput
   return Self::CONDITION_OK;
 }
 
+TypedStreamOutput::Condition
+TypedStreamOutput
+::WriteIntArray( const char* key, const long long int* array, const int size, const int valuesPerLine )
+{
+  if ( !array || size < 1) 
+    {
+    this->m_Status = Self::ERROR_ARG;
+    return Self::CONDITION_ERROR;
+    }
+  
+  int currentLevel = LevelStack.size();
+  if ( GzFile ) 
+    {
+    for ( int level = 0; level < currentLevel; level++)
+      gzputs( GzFile, "\t" );
+    
+    gzprintf( this->GzFile, "%s ", key );
+    
+    for ( int i = 0; i < size; i++) 
+      {
+      if (i && (i % valuesPerLine) == 0) 
+	{
+	gzprintf( GzFile, "\n\t");
+	for ( int level = 0; level < currentLevel; level++ )
+	  gzputs( GzFile, "\t" );
+	}
+      gzprintf( GzFile, "%ld ", array[i] );
+      }
+    
+    gzputs( GzFile, "\n" );
+    } 
+  else
+    {
+    for ( int level = 0; level < currentLevel; level++)
+      fputs( "\t", File );
+    
+    fprintf( File, "%s ", key );
+    
+    for ( int i = 0; i < size; i++) 
+      {
+      if (i && (i % valuesPerLine) == 0) 
+	{
+	fprintf( File, "\n\t");
+	for ( int level = 0; level < currentLevel; level++ )
+	  fputs( "\t", File );
+	}
+      fprintf( File, "%ld ", array[i] );
+      }
+    
+    fputs( "\n", File);
+    }
+  
+  return Self::CONDITION_OK;
+}
+
 TypedStreamOutput::Condition
 TypedStreamOutput
 ::WriteBoolArray( const char* key, const byte* array, const int size, const int valuesPerLine )
