@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2016 Google, Inc.
+//
 //  Copyright 1997-2009 Torsten Rohlfing
 //
 //  Copyright 2004-2013 SRI International
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4867 $
+//  $Revision: 5398 $
 //
-//  $LastChangedDate: 2013-09-24 10:06:53 -0700 (Tue, 24 Sep 2013) $
+//  $LastChangedDate: 2016-01-14 18:29:18 -0800 (Thu, 14 Jan 2016) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -183,6 +185,11 @@ public:
 				      const int size /*!< Number of values in the array. This is the number of values written to the archive. */,
 				      const int valuesPerLine = 10 /*!< Optional number of values per line of text written to the archive. This improves readability of the resulting archive as a text. */ );
 
+  Self::Condition WriteIntArray( const char* key /*!< The name of the field under which to write this array in the archive.*/, 
+				      const long long int* array /*!< Pointer to the array to be written.*/, 
+				      const int size /*!< Number of values in the array. This is the number of values written to the archive. */,
+				      const int valuesPerLine = 10 /*!< Optional number of values per line of text written to the archive. This improves readability of the resulting archive as a text. */ );
+
   /** Write array of binay encoded boole values to an open archive.
    */
   Self::Condition WriteBoolArray( const char* key /*!< The name of the field under which to write this array in the archive.*/, 
