@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4427 $
+//  $Revision: 4447 $
 //
-//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2012-07-06 13:51:04 -0700 (Fri, 06 Jul 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -168,9 +168,7 @@ VolumeFromFile::ReadBioRad( const std::string& path )
   dataArray->ChangeEndianness();
 #endif
   
-  const Types::Coordinate volSize[3] = { (dims[0] - 1) * lensScale * pixelsizeX, (dims[1] - 1) * lensScale * pixelsizeY, (dims[2] - 1) * pixelsizeZ };
-  
-  UniformVolume::SmartPtr volume( new UniformVolume( DataGrid::IndexType::FromPointer( dims ), UniformVolume::CoordinateVectorType::FromPointer( volSize ), dataArray ) );
+  UniformVolume::SmartPtr volume( new UniformVolume( DataGrid::IndexType::FromPointer( dims ), lensScale * pixelsizeX, lensScale * pixelsizeY, lensScale * pixelsizeZ, dataArray ) );
 
   if ( flipX )
     {
