@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2012, 2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4260 $
+//  $Revision: 5224 $
 //
-//  $LastChangedDate: 2012-04-25 16:34:20 -0700 (Wed, 25 Apr 2012) $
+//  $LastChangedDate: 2014-03-11 16:38:30 -0700 (Tue, 11 Mar 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -72,6 +72,9 @@ protected:
   /// Write transformation to filesystem.
   static void WriteNrrd( const Xform* xform, const std::string& path );
 #endif // #ifdef CMTK_BUILD_NRRD
+
+  /// Write transformation to filesystem.
+  static void WriteNIFTI( const Xform* xform, const std::string& path );
 };
 
 //@}
