@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2010, 2013 SRI International
+//  Copyright 2004-2010, 2013-2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 5129 $
+//  $Revision: 5166 $
 //
-//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
+//  $LastChangedDate: 2014-01-13 14:26:33 -0800 (Mon, 13 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -36,6 +36,8 @@
 
 #include <System/cmtkExitException.h>
 
+#include <Base/cmtkPolynomial.h>
+
 cmtk::XformList
 cmtk::XformListIO::MakeFromStringList( const std::vector<std::string>& stringList )
 {
@@ -69,6 +71,12 @@ cmtk::XformListIO::MakeFromStringList( const std::vector<std::string>& stringLis
       StdErr << "ERROR: singular matrix encountered reading transformation from " << *it << "\n";
       throw ExitException( 1 );
       }
+    catch ( const PolynomialHelper::DegreeUnsupported& ex )
+      {
+      StdErr << "ERROR: polynomial degree unsupported in " << *it << "\n";
+      StdErr << ex.what() << "\n";
+      throw ExitException( 1 );
+      }
     }
   
   return xformList;
