@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3193 $
+//  $Revision: 4973 $
 //
-//  $LastChangedDate: 2011-04-28 16:15:14 -0700 (Thu, 28 Apr 2011) $
+//  $LastChangedDate: 2013-10-11 13:31:38 -0700 (Fri, 11 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -99,64 +99,6 @@ void aux2x2schur(ap::real_value_type& a,
 ap::real_value_type extschursign(ap::real_value_type a, ap::real_value_type b);
 int extschursigntoone(ap::real_value_type b);
 
-/*************************************************************************
-Subroutine performing  the  Schur  decomposition  of  a  matrix  in  upper
-Hessenberg form using the QR algorithm with multiple shifts.
-
-The  source matrix  H  is  represented as  S'*H*S = T, where H - matrix in
-upper Hessenberg form,  S - orthogonal matrix (Schur vectors),   T - upper
-quasi-triangular matrix (with blocks of sizes  1x1  and  2x2  on  the main
-diagonal).
-
-Input parameters:
-    H   -   matrix to be decomposed.
-            Array whose indexes range within [1..N, 1..N].
-    N   -   size of H, N>=0.
-
-
-Output parameters:
-    H      contains the matrix T.
-            Array whose indexes range within [1..N, 1..N].
-            All elements below the blocks on the main diagonal are equal
-            to 0.
-    S   -   contains Schur vectors.
-            Array whose indexes range within [1..N, 1..N].
-
-Note 1:
-    The block structure of matrix T could be easily recognized: since  all
-    the elements  below  the blocks are zeros, the elements a[i+1,i] which
-    are equal to 0 show the block border.
-
-Note 2:
-    the algorithm  performance  depends  on  the  value  of  the  internal
-    parameter NS of InternalSchurDecomposition  subroutine  which  defines
-    the number of shifts in the QR algorithm (analog of  the  block  width
-    in block matrix algorithms in linear algebra). If you require  maximum
-    performance  on  your  machine,  it  is  recommended  to  adjust  this
-    parameter manually.
-
-Result:
-    True, if the algorithm has converged and the parameters H and S contain
-        the result.
-    False, if the algorithm has not converged.
-
-Algorithm implemented on the basis of subroutine DHSEQR (LAPACK 3.0 library).
-*************************************************************************/
-bool upperhessenbergschurdecomposition(ap::real_2d_array& h,
-     int n,
-     ap::real_2d_array& s)
-{
-    bool result;
-    ap::real_1d_array wi;
-    ap::real_1d_array wr;
-    int info;
-
-    internalschurdecomposition(h, n, 1, 2, wr, wi, s, info);
-    result = info==0;
-    return result;
-}
-
-
 void internalschurdecomposition(ap::real_2d_array& h,
      int n,
      int tneeded,
@@ -237,9 +179,13 @@ void internalschurdecomposition(ap::real_2d_array& h,
     workv3.setbounds(1, 3);
     tmpwr.setbounds(1, ap::maxint(n, 1));
     tmpwi.setbounds(1, ap::maxint(n, 1));
+
+#ifndef NO_AP_ASSERT
     ap::ap_error::make_assertion(n>=0, "InternalSchurDecomposition: incorrect N!");
     ap::ap_error::make_assertion(tneeded==0||tneeded==1, "InternalSchurDecomposition: incorrect TNeeded!");
     ap::ap_error::make_assertion(zneeded==0||zneeded==1||zneeded==2, "InternalSchurDecomposition: incorrect ZNeeded!");
+#endif
+
     wantt = tneeded==1;
     initz = zneeded==2;
     wantz = zneeded!=0;
