@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4100 $
+//  $Revision: 4882 $
 //
-//  $LastChangedDate: 2012-03-29 14:30:03 -0700 (Thu, 29 Mar 2012) $
+//  $LastChangedDate: 2013-09-27 15:16:36 -0700 (Fri, 27 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -58,7 +58,7 @@ const char *Colormap::StandardColormaps[] =
 Colormap::Colormap()
 {
   TableEntries = 256;
-  SetStandardColormap( PALETTE_GRAY );
+  Gamma = 0;
   DataRange[0] = 0;
   DataRange[1] = 4095;
   HueRange[0] = 0;
@@ -67,10 +67,12 @@ Colormap::Colormap()
   ValueRange[1] = 4095;
   SaturationRange[0] = 0;
   SaturationRange[1] = 4095;
-  Gamma = 0;
   Reverse = false;
+  this->InvDataRangeWidth = 4095;
 
   CreateSystemLabelColorMap( this->LabelColorMap );
+
+  this->SetStandardColormap( PALETTE_GRAY );
 }
 
 void 
