@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4397 $
+//  $Revision: 4812 $
 //
-//  $LastChangedDate: 2012-05-31 11:38:48 -0700 (Thu, 31 May 2012) $
+//  $LastChangedDate: 2013-09-09 14:26:32 -0700 (Mon, 09 Sep 2013) $
 //
-//  $LastChangedBy: torsten_at_home $
+//  $LastChangedBy: torstenrohlfing $
 //
 */
 
@@ -73,7 +73,7 @@ public:
 
   /** Copy non-pipelined scalar image.
    */
-  void SetFromScalarImage( const ScalarImage* scalarImage );
+  void SetFromScalarImage( const ScalarImage& scalarImage );
 
   /** Return data at a certain grid location (pixel).
    *\param x Index of requested pixel in x-direction. Valid range is 
