@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2016 Google, Inc.
+//
 //  Copyright 1997-2009 Torsten Rohlfing
 //
 //  Copyright 2004-2010, 2013 SRI International
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4934 $
+//  $Revision: 5401 $
 //
-//  $LastChangedDate: 2013-10-04 10:32:06 -0700 (Fri, 04 Oct 2013) $
+//  $LastChangedDate: 2016-01-14 19:47:47 -0800 (Thu, 14 Jan 2016) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -42,7 +44,7 @@ cmtk
 {
 
 InverseInterpolationVolumeReconstructionBase
-::InverseInterpolationVolumeReconstructionBase( const UniformVolume* originalImage, const int interleaveFactor, const int interleaveAxis )
+::InverseInterpolationVolumeReconstructionBase( const UniformVolume* originalImage, const Types::GridIndexType interleaveFactor, const int interleaveAxis )
   : VolumeInjectionReconstruction( originalImage, interleaveFactor, interleaveAxis ),
     m_RegionalIntensityTruncation( true ),
     m_LowestMaxError( 1e12 ),
