@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4426 $
+//  $Revision: 4816 $
 //
-//  $LastChangedDate: 2012-06-12 10:30:56 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2013-09-10 10:06:43 -0700 (Tue, 10 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -58,6 +58,7 @@ ElasticRegistration::ElasticRegistration ()
     InverseWarpXform( NULL ),
     ForceSwitchVolumes( false ),
     m_MatchFltToRefHistogram( false ),
+    m_ExactGridSpacing( false ),
     m_RigidityConstraintMap( NULL ),
     m_InverseConsistencyWeight( 0.0 ),
     m_RelaxToUnfold( false ),
