@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4423 $
+//  $Revision: 5129 $
 //
-//  $LastChangedDate: 2012-06-11 16:13:37 -0700 (Mon, 11 Jun 2012) $
+//  $LastChangedDate: 2014-01-09 13:48:15 -0800 (Thu, 09 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -93,34 +93,24 @@ ElasticRegistrationCommandLine* ElasticRegistrationCommandLine::StaticThis = NUL
 
 ElasticRegistrationCommandLine
 ::ElasticRegistrationCommandLine
-( const int argc, const char *argv[] ) :
-#ifdef CMTK_USE_SQLITE
-  m_UpdateDB( NULL ),
-#endif
-  m_OutputPathITK( NULL ),
-  m_ReformattedImagePath( NULL )
+( const int argc, const char *argv[] )
 {
   this->m_Metric = 0;
   this->m_Algorithm = 3;
 
   this->m_GridSpacing = 15;
   this->m_ExactGridSpacing = 0;
-  Studylist = Protocol = Time = NULL;
-
   this->m_OutputIntermediate = 0;
 
-  InputStudylist = NULL;
-  const char *initialTransformationFile = NULL;
+  std::string initialTransformationFile;
   IntermediateResultIndex = 0;
 
-  this->RigidityConstraintMapFilename = NULL;
-
   bool forceOutsideFlag = false;
   Types::DataItem forceOutsideValue = 0;
 
-  const char* clArg1 = NULL; // input studylist or reference image
-  const char* clArg2 = NULL; // empty or floating image
-  const char* clArg3 = NULL; // empty or initial transformation
+  std::string clArg1; // input studylist or reference image
+  std::string clArg2; // empty or floating image
+  std::string clArg3; // empty or initial transformation
 
   try
     {
@@ -209,10 +199,8 @@ ElasticRegistrationCommandLine
     cl.EndGroup();
 #endif
 
-    cl.AddParameter( &clArg1, "ReferenceImage", "Reference (fixed) image path" )
-      ->SetProperties( CommandLine::PROPS_IMAGE );
-    cl.AddParameter( &clArg2, "FloatingImage", "Floating (moving) image path" )
-      ->SetProperties( CommandLine::PROPS_IMAGE | CommandLine::PROPS_OPTIONAL);
+    cl.AddParameter( &clArg1, "ReferenceImage", "Reference (fixed) image path" )->SetProperties( CommandLine::PROPS_IMAGE );
+    cl.AddParameter( &clArg2, "FloatingImage", "Floating (moving) image path" )->SetProperties( CommandLine::PROPS_IMAGE | CommandLine::PROPS_OPTIONAL);
     cl.AddParameter( &clArg3, "InitialXform", "Initial affine transformation from reference to floating image" )
       ->SetProperties( CommandLine::PROPS_NOXML | CommandLine::PROPS_XFORM | CommandLine::PROPS_OPTIONAL );
 
@@ -221,23 +209,23 @@ ElasticRegistrationCommandLine
   catch ( const CommandLine::Exception& ex )
     {
     StdErr << ex << "\n";
-    exit( 1 );
+    throw ExitException( 1 );
     }
 
   if ( (OptimizerStepFactor <= 0) || (OptimizerStepFactor >= 1) ) 
     {
     StdErr << "ERROR: step factor value " << OptimizerStepFactor << " is invalid. Must be in range (0..1)\n";
-    exit( 1 );
+    throw ExitException( 1 );
     }
 
-  if ( clArg2 ) 
+  if ( ! clArg2.empty() ) 
     {
     this->SetInitialTransformation( AffineXform::SmartPtr( new AffineXform() ) );
     
-    Study1 = const_cast<char*>( clArg1 );
-    Study2 = const_cast<char*>( clArg2 );
+    this->Study1 = clArg1;
+    this->Study2 = clArg2;
 
-    if ( clArg3 )
+    if ( ! clArg3.empty() )
       {
       initialTransformationFile = clArg3;
       }
@@ -252,13 +240,13 @@ ElasticRegistrationCommandLine
     if ( ! classStream.IsValid() ) 
       {
       StdErr << "ERROR: Could not open studylist archive " << InputStudylist << ".\n";
-      exit( 1 );
+      throw ExitException( 1 );
       }
     
     classStream.Seek ( "registration" );
-    Study1 = classStream.ReadString( "reference_study" );
-    Study2 = classStream.ReadString( "floating_study" );
-    if ( Study2 )
+    Study1 = classStream.ReadStdString( "reference_study" );
+    Study2 = classStream.ReadStdString( "floating_study" );
+    if ( ! Study2.empty() )
       {
       AffineXform::SmartPtr affineXform;
       classStream >> affineXform;
@@ -267,27 +255,44 @@ ElasticRegistrationCommandLine
     else
       {
       // legacy studylists have inverse transformation stored in them
-      Study2 = classStream.ReadString( "model_study" );
+      Study2 = classStream.ReadStdString( "model_study" );
       AffineXform::SmartPtr affineXform;
       classStream >> affineXform;
-      this->SetInitialTransformation( affineXform->GetInverse() );
+
+      try
+	{
+	this->SetInitialTransformation( affineXform->GetInverse() );
+	}
+      catch ( const AffineXform::MatrixType::SingularMatrixException& )	
+	{
+	StdErr << "ERROR: singular matrix read from initialization file in cmtk::ElasticRegistrationCommandLine constructor\n";
+	throw ExitException( 1 );
+	}
       }
     
     classStream.Close();
     }
 
   /// Was an initial studylist given? If so, get warp 
-  if ( initialTransformationFile ) 
+  if ( ! initialTransformationFile.empty() ) 
     {
-    Xform::SmartPtr initialXform( XformIO::Read( initialTransformationFile ) );
-    AffineXform::SmartPtr affineXform = AffineXform::SmartPtr::DynamicCastFrom( initialXform );
-    if ( affineXform )
+    try
       {
-      this->SetInitialTransformation( affineXform );
+      Xform::SmartPtr initialXform( XformIO::Read( initialTransformationFile ) );
+      AffineXform::SmartPtr affineXform = AffineXform::SmartPtr::DynamicCastFrom( initialXform );
+      if ( affineXform )
+	{
+	this->SetInitialTransformation( affineXform );
+	}
+      else
+	{
+	InitialWarpXform = SplineWarpXform::SmartPtr::DynamicCastFrom( initialXform );
+	}
       }
-    else
+    catch ( const Exception& ex )
       {
-      InitialWarpXform = SplineWarpXform::SmartPtr::DynamicCastFrom( initialXform );
+      StdErr << "Initializing transformation from " << initialTransformationFile << " failed: " << ex.what() << "\n";
+      throw( ExitException( 1 ) );
       }
     }
 
@@ -298,11 +303,11 @@ ElasticRegistrationCommandLine
     this->SetInitialTransformation( AffineXform::SmartPtr( dynamic_cast<AffineXform*>( this->m_InitialTransformation->MakeInverse() ) ) );
     }
   
-  UniformVolume::SmartPtr volume( VolumeIO::ReadOriented( Study1 ) );
+  UniformVolume::SmartPtr volume( VolumeIO::ReadOriented( this->Study1 ) );
   if ( !volume ) throw ConstructorFailed();
   this->SetVolume_1( UniformVolume::SmartPtr( this->m_PreprocessorRef.GetProcessedImage( volume ) ) );
 
-  volume = UniformVolume::SmartPtr( VolumeIO::ReadOriented( Study2 ) );
+  volume = UniformVolume::SmartPtr( VolumeIO::ReadOriented( this->Study2 ) );
   if ( !volume ) throw ConstructorFailed();
   this->SetVolume_2( UniformVolume::SmartPtr( this->m_PreprocessorFlt.GetProcessedImage( volume ) ) );
 
@@ -311,14 +316,22 @@ ElasticRegistrationCommandLine
     {
     if ( affineXform->MetaKeyExists( META_SPACE ) && (affineXform->GetMetaInfo( META_SPACE ) != AnatomicalOrientation::ORIENTATION_STANDARD ) )
       {
-      TransformChangeFromSpaceAffine toStandardSpace( *affineXform, *(this->m_Volume_1), *(this->m_Volume_2), affineXform->GetMetaInfo(META_SPACE).c_str() );
-      *affineXform = toStandardSpace.GetTransformation();
-      affineXform->SetMetaInfo( META_SPACE, AnatomicalOrientation::ORIENTATION_STANDARD );
-      this->SetInitialTransformation( affineXform );
+      try 
+	{
+	TransformChangeFromSpaceAffine toStandardSpace( *affineXform, *(this->m_Volume_1), *(this->m_Volume_2), affineXform->GetMetaInfo(META_SPACE).c_str() );
+	*affineXform = toStandardSpace.GetTransformation();
+	affineXform->SetMetaInfo( META_SPACE, AnatomicalOrientation::ORIENTATION_STANDARD );
+	this->SetInitialTransformation( affineXform );
+	}
+      catch ( const AffineXform::MatrixType::SingularMatrixException& )
+	{
+	StdErr << "ERROR: singular matrix cannot be inverted to change transformation to standard space in ElasticRegistrationCommandLine constructor.\n";
+	throw ExitException( 1 );
+	}
       }
     }
   
-  if ( this->RigidityConstraintMapFilename )
+  if ( !this->RigidityConstraintMapFilename.empty() )
     {
     UniformVolume::SmartPtr rigidityWeightMap( VolumeIO::ReadOriented( this->RigidityConstraintMapFilename ) );
     if ( rigidityWeightMap )
@@ -328,7 +341,7 @@ ElasticRegistrationCommandLine
     else
       {
       StdErr << "ERROR: rigidity constraint mapcould not be read from " << this->RigidityConstraintMapFilename << "\n";
-      exit( 1 );
+      throw ExitException( 1 );
       }
     }
 
@@ -337,7 +350,7 @@ ElasticRegistrationCommandLine
     this->SetForceOutside( true, forceOutsideValue );
     }
 
-  if ( Protocol )
+  if ( !Protocol.empty() )
     {
     RegistrationCallback::SmartPtr callback( new ProtocolCallback( Protocol ) );
     this->SetCallback( callback );
@@ -377,7 +390,7 @@ ElasticRegistrationCommandLine
 ::OutputResult
 ( const CoordinateVector*, const CallbackResult irq )
 {
-  if ( Studylist ) 
+  if ( ! this->Studylist.empty() ) 
     {
     std::string path( this->Studylist );
     if ( irq != CALLBACK_OK )
@@ -386,39 +399,37 @@ ElasticRegistrationCommandLine
     this->OutputWarp( path.c_str() );
     }
 
-  if ( this->m_OutputPathITK ) 
+  if ( !this->m_OutputPathITK.empty() ) 
     {
-    std::string path( this->m_OutputPathITK );
     if ( irq != CALLBACK_OK )
-      path.append( "-partial" );
-    
-    SplineWarpXformITKIO::Write( path.c_str(), *(this->GetTransformation()), *(this->m_ReferenceVolume), *(this->m_FloatingVolume) );
+      SplineWarpXformITKIO::Write( this->m_OutputPathITK + "-partial", *(this->GetTransformation()), *(this->m_ReferenceVolume), *(this->m_FloatingVolume) );
+    else
+      SplineWarpXformITKIO::Write( this->m_OutputPathITK, *(this->GetTransformation()), *(this->m_ReferenceVolume), *(this->m_FloatingVolume) );
     }
 
-  if ( this->m_ReformattedImagePath )
+  if ( !this->m_ReformattedImagePath.empty() )
     {
-    std::string path( this->m_ReformattedImagePath );
     if ( irq != CALLBACK_OK )
-      path.append( "-partial" );
-    
-    VolumeIO::Write( *(this->GetReformattedFloatingImage()), path.c_str() );
+      VolumeIO::Write( *(this->GetReformattedFloatingImage()), this->m_ReformattedImagePath + "-partial" );
+    else
+      VolumeIO::Write( *(this->GetReformattedFloatingImage()), this->m_ReformattedImagePath );
     }
 
 #ifdef CMTK_USE_SQLITE
-  if ( this->m_UpdateDB && (irq == CALLBACK_OK) )
+  if ( (irq == CALLBACK_OK) && !this->m_UpdateDB.empty() )
     {
     try
       {
       ImageXformDB db( this->m_UpdateDB );
       
-      if ( this->m_ReformattedImagePath )
+      if ( !this->m_ReformattedImagePath.empty() )
 	{
 	db.AddImage( this->m_ReformattedImagePath, this->m_ReferenceVolume->GetMetaInfo( META_FS_PATH ) );
 	}
       
-      if ( this->Studylist )
+      if ( ! this->Studylist.empty() )
 	{
-	if ( this->InputStudylist ) 
+	if ( ! this->InputStudylist.empty() ) 
 	  {
 	  db.AddRefinedXform( this->Studylist, true /*invertible*/, this->InputStudylist, this->ForceSwitchVolumes );
 	  }
@@ -456,7 +467,7 @@ ElasticRegistrationCommandLine::DoneResolution
 }
 
 void
-ElasticRegistrationCommandLine::OutputWarp ( const char* path ) const
+ElasticRegistrationCommandLine::OutputWarp ( const std::string& path ) const
 {
   ClassStreamOutput classStream( path, "studylist", ClassStreamOutput::MODE_WRITE );
   if ( ! classStream.IsValid() ) return;
@@ -490,7 +501,7 @@ ElasticRegistrationCommandLine::OutputWarp ( const char* path ) const
   classStream.WriteInt( "ignore_edge", IgnoreEdge );
   classStream.WriteDouble( "jacobian_constraint_weight", this->m_JacobianConstraintWeight );
   classStream.WriteDouble( "rigidity_constraint_weight", this->m_RigidityConstraintWeight );
-  if ( this->RigidityConstraintMapFilename )
+  if ( !this->RigidityConstraintMapFilename.empty() )
     {
     classStream.WriteString( "rigidity_constraint_map_filename", RigidityConstraintMapFilename );
     }
@@ -557,9 +568,9 @@ void
 ElasticRegistrationCommandLine::OutputIntermediate( const bool incrementCount )
 {
   char path[PATH_MAX];
-  if ( Studylist ) 
+  if ( ! this->Studylist.empty() ) 
     {
-    snprintf( path, sizeof( path ), "%s%clevel-%02d.list", Studylist, (int)CMTK_PATH_SEPARATOR, IntermediateResultIndex );
+    snprintf( path, sizeof( path ), "%s%clevel-%02d.list", Studylist.c_str(), (int)CMTK_PATH_SEPARATOR, IntermediateResultIndex );
     } 
   else
     {
@@ -577,9 +588,9 @@ CallbackResult ElasticRegistrationCommandLine::Register ()
   CallbackResult Result = this->Superclass::Register();
   const int elapsed = static_cast<int>( Timers::GetTimeProcess() - baselineTime );
 
-  if ( Time ) 
+  if ( !this->Time.empty() ) 
     {
-    FILE *tfp = fopen( Time, "w" );
+    FILE *tfp = fopen( this->Time.c_str(), "w" );
     
     if ( tfp ) 
       {
