@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3728 $
+//  $Revision: 4427 $
 //
-//  $LastChangedDate: 2012-01-19 14:23:36 -0800 (Thu, 19 Jan 2012) $
+//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -113,7 +113,7 @@ GroupwiseRegistrationFunctionalAffineInitializer::InitializeXforms
   // convert first order moments to scale with average log factor 0
   if ( initScales )
     {
-    UniformVolume::CoordinateVectorType avgScales( UniformVolume::CoordinateVectorType::Init( 0 ) );
+    UniformVolume::CoordinateVectorType avgScales( 0.0 );
     UniformVolume::CoordinateVectorType fom0( firstOrderMoments[0] );
     for ( size_t imageIdx = 0; imageIdx < numberOfImages; ++imageIdx )
       {
