@@ -4,6 +4,8 @@
 //
 //  Copyright 2004-2011, 2013 SRI International
 //
+//  Copyright 2015 Google, Inc.
+//
 //  This file is part of the Computational Morphometry Toolkit.
 //
 //  http://www.nitrc.org/projects/cmtk/
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4879 $
+//  $Revision: 5393 $
 //
-//  $LastChangedDate: 2013-09-26 15:08:17 -0700 (Thu, 26 Sep 2013) $
+//  $LastChangedDate: 2015-11-06 20:39:27 -0800 (Fri, 06 Nov 2015) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -39,6 +41,7 @@
 #include <System/cmtkSmartPtr.h>
 #include <Registration/cmtkReformatVolume.h>
 #include <Base/cmtkInterpolator.h>
+#include <Base/cmtkTypes.h>
 
 namespace
 cmtk
@@ -93,6 +96,7 @@ public:
   /// Reformat and write average image.
   bool WriteAverageImage( const char* path /*<! Path of output image.*/,
 			  const cmtk::Interpolators::InterpolationEnum interp = cmtk::Interpolators::LINEAR /*!< Selection of interpolation method (via igsReformatVolume).*/,
+			  const cmtk::ScalarDataType pixelType = cmtk::TYPE_FLOAT /*!< Scalar data type for the average image. */,
 			  const bool useTemplateData = false /*!< If true, template image data is included in averaging.*/ );
   
 private:
