@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  Copyright 1997-2010 Torsten Rohlfing
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4427 $
+//  $Revision: 4877 $
 //
-//  $LastChangedDate: 2012-06-12 11:23:22 -0700 (Tue, 12 Jun 2012) $
+//  $LastChangedDate: 2013-09-24 13:25:18 -0700 (Tue, 24 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -54,7 +54,11 @@ cmtk
 ImagePairNonrigidRegistrationFunctional::ImagePairNonrigidRegistrationFunctional
 ( UniformVolume::SmartPtr& reference, UniformVolume::SmartPtr& floating )
   : ImagePairRegistrationFunctional( reference, floating ),
-    m_ActiveCoordinates( NULL )
+    m_ActiveCoordinates( NULL ),
+    m_JacobianConstraintWeight( 0.0 ),
+    m_GridEnergyWeight( 0.0 ),
+    m_InverseConsistencyWeight( 0.0 ),
+    m_Regularize( false )
 {
   this->m_NumberOfThreads = ThreadPool::GetGlobalThreadPool().GetNumberOfThreads();
   this->m_NumberOfTasks = 4 * this->m_NumberOfThreads - 3;
