@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4365 $
+//  $Revision: 4834 $
 //
-//  $LastChangedDate: 2012-05-29 15:46:27 -0700 (Tue, 29 May 2012) $
+//  $LastChangedDate: 2013-09-12 15:15:51 -0700 (Thu, 12 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -160,7 +160,7 @@ private:
   const char* m_SymmetryParametersFile;
 
   /// Input image file path.
-  const char* m_InFileName;
+  std::string m_InFileName;
   
 /// Constants for initial plane orientation.
   typedef enum
