@@ -1,5 +1,7 @@
 /*
 //
+//  Copyright 2016 Google, Inc.
+//
 //  Copyright 1997-2009 Torsten Rohlfing
 //
 //  Copyright 2004-2009, 2013 SRI International
@@ -22,9 +24,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4835 $
+//  $Revision: 5418 $
 //
-//  $LastChangedDate: 2013-09-12 15:48:47 -0700 (Thu, 12 Sep 2013) $
+//  $LastChangedDate: 2016-01-20 20:15:12 -0800 (Wed, 20 Jan 2016) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -91,13 +93,13 @@ ProtocolCallback::ExecuteWithData
 }
 
 void
-ProtocolCallback::Comment ( const std::string& comment )
+ProtocolCallback::Comment ( const char* comment )
 {
   if ( fp ) 
     {
-    if ( !comment.empty() ) 
+    if ( comment != NULL ) 
       {
-      fprintf( fp, "# %s\n", comment.c_str() );
+      fprintf( fp, "# %s\n", comment );
       fflush( fp );
       } 
     else
@@ -109,8 +111,8 @@ ProtocolCallback::Comment ( const std::string& comment )
   
   if ( Debug )
     {
-    if ( !comment.empty() )
-      fprintf( stderr, "# %s\n", comment.c_str() );
+    if ( comment != NULL )
+      fprintf( stderr, "# %s\n", comment );
     else
       fputs( "#\n", stderr );
     }
