@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4538 $
+//  $Revision: 4882 $
 //
-//  $LastChangedDate: 2012-10-02 15:16:13 -0700 (Tue, 02 Oct 2012) $
+//  $LastChangedDate: 2013-09-27 15:16:36 -0700 (Fri, 27 Sep 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -63,14 +63,19 @@ cmtk
 /** \addtogroup Registration */
 //@{
 ReformatVolume::ReformatVolume() 
-  : m_UserDataType( TYPE_NONE ),
+  : m_LowerThresholdReference( 0.0 ),
+    m_LowerThresholdFloating( 0.0 ),
+    m_UpperThresholdReference( 0.0 ),
+    m_UpperThresholdFloating( 0.0 ),
+    m_UsePaddingValue( false ),
+    m_PaddingValue( 0.0 ),
+    Interpolation( cmtk::Interpolators::LINEAR ),
+    m_UserDataType( TYPE_NONE ),
     ReferenceVolume( NULL ),
     FloatingVolume( NULL ),
     m_AffineXform( NULL ),
     m_WarpXform( NULL )
 {
-  Interpolation = cmtk::Interpolators::LINEAR;
-  this->m_UsePaddingValue = false;
 }
 
 void
@@ -325,10 +330,10 @@ ReformatVolume::GetTransformedReferenceLabel( void *const arg )
 	const bool success = splineXform->ApplyInverse( xyz, v, 0.1 * minDelta );
 	u = v;
 	
-	bool valid = false;
 	unsigned int toIdx = 0;
 	if ( success ) 
 	  {
+	  bool valid = false;
 	  if ( params->IncludeReferenceData ) 
 	    {
 	    valid = thisObject->ReferenceVolume->ProbeNoXform( probe[toIdx], v );
