@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2012 Torsten Rohlfing
 //
-//  Copyright 2004-2011 SRI International
+//  Copyright 2004-2011, 2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,11 +22,11 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4243 $
+//  $Revision: 4877 $
 //
-//  $LastChangedDate: 2012-04-21 20:59:34 -0700 (Sat, 21 Apr 2012) $
+//  $LastChangedDate: 2013-09-24 13:25:18 -0700 (Tue, 24 Sep 2013) $
 //
-//  $LastChangedBy: torsten_at_home $
+//  $LastChangedBy: torstenrohlfing $
 //
 */
 
@@ -107,7 +107,14 @@ public:
     }
     
     /// Default constructor.
-    ImageData() : Padding( DataTypeTraits<T>::ChoosePaddingValue() ), Data( NULL ), DataArray( NULL )
+    ImageData() : 
+      Padding( DataTypeTraits<T>::ChoosePaddingValue() ), 
+      Data( NULL ), 
+      DataArray( NULL ), 
+      BinOffset( 0 ),
+      BinWidth( 0 ),
+      m_ValueRange( 0, 0 ),
+      NumberOfSamples( 0 )
     {
       nextJ = nextK = nextIJ = nextJK = nextIK = nextIJK = 0;
     }
