@@ -1,6 +1,6 @@
 /*
 //
-//  Copyright 2012 SRI International
+//  Copyright 2012, 2014 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -20,9 +20,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4381 $
+//  $Revision: 5189 $
 //
-//  $LastChangedDate: 2012-05-30 14:18:15 -0700 (Wed, 30 May 2012) $
+//  $LastChangedDate: 2014-01-29 14:51:25 -0800 (Wed, 29 Jan 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -64,17 +64,15 @@ LeastSquaresPolynomialIntensityBiasField::LeastSquaresPolynomialIntensityBiasFie
   avg /= nPixelsMask;
 
   // set up least-squares problem
-  size_t nVars = 0;
-  switch ( degree )
-    {
-    case 1: nVars = Polynomial<1,Types::DataItem>::NumberOfMonomials; break;
-    case 2: nVars = Polynomial<2,Types::DataItem>::NumberOfMonomials; break;
-    case 3: nVars = Polynomial<3,Types::DataItem>::NumberOfMonomials; break;
-    case 4: nVars = Polynomial<4,Types::DataItem>::NumberOfMonomials; break;
+  const size_t nVars = PolynomialHelper::GetNumberOfMonomials( degree );
+  if ( nVars < 2 )
+    { // we ignore constant term, so we need at least 2 variables to be able to do anything meningful. for fewer, just use original data
+    this->m_CorrectedData = image.GetData();
+    return;
     }
 
   std::vector<Types::DataItem> dataVector( nPixelsMask );
-  Matrix2D<Types::DataItem> uMatrix( nPixelsMask, nVars );
+  Matrix2D<Types::DataItem> uMatrix( nPixelsMask, nVars-1 ); // nVars-1 because we ignore zero-order term
 
   size_t cntPx = 0;
   for ( RegionIndexIterator<DataGrid::RegionType> it( region ); it != it.end(); ++it )
@@ -85,9 +83,9 @@ LeastSquaresPolynomialIntensityBiasField::LeastSquaresPolynomialIntensityBiasFie
       {
       const UniformVolume::CoordinateVectorType xyz = ComponentDivide( image.GetGridLocation( it.Index() ) - center, image.m_Size );
       dataVector[cntPx] = image.GetDataAt( ofs ) / avg - 1.0;
-      for ( size_t n = 0; n < nVars; ++n )
+      for ( size_t n = 1; n < nVars; ++n )
 	{
-	uMatrix[cntPx][n] = Polynomial<4,Types::DataItem>::EvaluateMonomialAt( n, xyz[0], xyz[1], xyz[2] );
+	uMatrix[cntPx][n-1] = Polynomial<4,Types::DataItem>::EvaluateMonomialAt( n, xyz[0], xyz[1], xyz[2] );
 	}
       ++cntPx;
       }
@@ -107,9 +105,9 @@ LeastSquaresPolynomialIntensityBiasField::LeastSquaresPolynomialIntensityBiasFie
     const UniformVolume::CoordinateVectorType xyz = ComponentDivide( image.GetGridLocation( it.Index() ) - center, image.m_Size );    
     
     Types::DataItem bias = 1.0;
-    for ( size_t n = 0; n < nVars; ++n )
+    for ( size_t n = 1; n < nVars; ++n )
       {
-      bias += params[n] * Polynomial<4,Types::DataItem>::EvaluateMonomialAt( n, xyz[0], xyz[1], xyz[2] );
+      bias += params[n-1] * Polynomial<4,Types::DataItem>::EvaluateMonomialAt( n, xyz[0], xyz[1], xyz[2] );
       }
     
     this->m_BiasData->Set( bias, ofs );
