@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3740 $
+//  $Revision: 5332 $
 //
-//  $LastChangedDate: 2012-01-25 13:59:07 -0800 (Wed, 25 Jan 2012) $
+//  $LastChangedDate: 2014-04-25 16:38:49 -0700 (Fri, 25 Apr 2014) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -80,14 +80,20 @@ CommandLine::PrintHelp
 	{
 	if ( ! (*it)->m_Comment.empty() )
 	  {
-	  fmt << (*it)->m_Name << " ";
+	  if ( (*it)->m_Properties & PROPS_OPTIONAL )
+	    fmt << "[" << (*it)->m_Name << "] ";
+	  else
+	    fmt << (*it)->m_Name << " ";
 	  }
 	}
       for ( NonOptionParameterVectorListType::const_iterator it = this->m_NonOptionParameterVectorList.begin(); it != this->m_NonOptionParameterVectorList.end(); ++it )
 	{
 	if ( ! (*it)->m_Comment.empty() )
 	  {
-	  fmt << (*it)->m_Name << " ";
+	  if ( (*it)->m_Properties & PROPS_OPTIONAL )
+	    fmt << "[" << (*it)->m_Name << " ... ] ";
+	  else
+	    fmt << (*it)->m_Name << " ... ";
 	  }
 	}
       StdOut.FormatText( fmt.str(), 5, lineWidth );
