@@ -4,6 +4,8 @@
 //
 //  Copyright 2004-2009 SRI International
 //
+//  Copyright 2015 Google, Inc.
+//
 //  This file is part of the Computational Morphometry Toolkit.
 //
 //  http://www.nitrc.org/projects/cmtk/
@@ -22,13 +24,14 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 3632 $
+//  $Revision: 5382 $
 //
-//  $LastChangedDate: 2011-12-16 14:09:28 -0800 (Fri, 16 Dec 2011) $
+//  $LastChangedDate: 2015-01-31 20:53:03 -0800 (Sat, 31 Jan 2015) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
 */
+
 #include "cmtkCommandLine.h"
 
 long int
@@ -36,7 +39,7 @@ cmtk::CommandLine::Item
 ::ConvertStrToLong( const char* str )
 {
   char* endptr;
-  const int value = strtol( str, &endptr, 0 );
+  const long int value = strtol( str, &endptr, 0 );
   if ( (endptr == str) || *endptr )
     {
     throw( Exception( "Option expects an integer argument" ) );
