@@ -2,7 +2,7 @@
 //
 //  Copyright 1997-2009 Torsten Rohlfing
 //
-//  Copyright 2004-2012 SRI International
+//  Copyright 2004-2013 SRI International
 //
 //  This file is part of the Computational Morphometry Toolkit.
 //
@@ -22,9 +22,9 @@
 //  with the Computational Morphometry Toolkit.  If not, see
 //  <http://www.gnu.org/licenses/>.
 //
-//  $Revision: 4296 $
+//  $Revision: 4918 $
 //
-//  $LastChangedDate: 2012-05-01 15:21:41 -0700 (Tue, 01 May 2012) $
+//  $LastChangedDate: 2013-10-03 13:01:32 -0700 (Thu, 03 Oct 2013) $
 //
 //  $LastChangedBy: torstenrohlfing $
 //
@@ -71,7 +71,7 @@ __attribute__((visibility("hidden"))) pthread_attr_t gomp_thread_attr;
 #  endif
 #endif
 
-#ifdef CMTK_USE_FFTW
+#ifdef CMTK_USE_FFTW_FOUND
 #  include <System/cmtkFFTW.h>
 #endif
 
@@ -93,32 +93,6 @@ Threads::GetNumberOfThreads()
   return Threads::NumberOfThreads;
 }
 
-bool
-Threads::Available()
-{
-#ifndef CMTK_USE_SMP
-  // Threads are not activated in this library.
-  return false;
-#else
-
-#ifdef _MSC_VER
-  // we know that threads are available on Windows32.
-  return true;
-#elif defined (__APPLE__)
-	// GJ Apple doesn't seem to provide these _SC_THREADS etc constants 
-	// in unistd.h -  I don't know how you get the info dynamically
-	// so just get it statically at compile time
-#ifdef _POSIX_THREADS
-  return true;
-#else
-  return false;
-#endif
-#else
-  return (sysconf(_SC_THREADS) == -1);
-#endif
-#endif
-}
-
 void
 Threads::SetNumberOfThreads( const long int numberOfThreads )
 {
@@ -256,7 +230,7 @@ Threads::RunThreads
     
     if ( status ) 
       {
-      fprintf( stderr, "Creation of thread #%d failed with status %d.\n", threadIdx, status );
+      fprintf( stderr, "Creation of thread #%u failed with status %d.\n", threadIdx, status );
 #if defined(CMTK_USE_SMP) && defined(CMTK_USE_PTHREADS)
       Thread[threadIdx] = 0;
 #endif
@@ -272,7 +246,7 @@ Threads::RunThreads
   // So we collect the shorter running ones first and give more time to the
   // longer running ones while dealing with the administrational overhead of
   // the ones that are already finished.
-  for ( int threadIdx = numberOfThreads-1; threadIdx; --threadIdx ) 
+  for ( unsigned threadIdx = numberOfThreads-1; threadIdx; --threadIdx ) 
     {
 #ifdef CMTK_USE_SMP
 #  ifdef _MSC_VER
@@ -328,7 +302,7 @@ Threads::CheckEnvironment()
     SetNumberOfThreads( std::min( Threads::GetNumberOfProcessors(), Threads::GetMaxThreads() ) );
     }
 
-#ifdef CMTK_USE_FFTW
+#ifdef CMTK_USE_FFTW_FOUND
   FFTW::GetStatic().SetNumberOfThreads( Threads::GetNumberOfThreads() );
 #endif
 
